Module aggregate_fn

Module aggregate_fn 

Aggregate function vtable machinery.

This module contains the AggregateFnVTable trait, the Accumulator trait, and the type-erasure infrastructure for aggregate functions.

Modules

fns
kernels
Pluggable aggregate function kernels used to provide encoding-specific implementations of aggregate functions.
session

Structs

Accumulator
An accumulator used for computing aggregates over an entire stream of arrays.
AggregateFn
A typed aggregate function instance, parameterized by a concrete AggregateFnVTable.
AggregateFnOptions
An opaque handle to aggregate function options.
AggregateFnRef
A type-erased aggregate function, pairing a vtable with bound options behind a trait object.
EmptyOptions
GroupedAccumulator
An accumulator used for computing grouped aggregates.

Traits

AggregateFnPlugin
Registry trait for ID-based deserialization of aggregate functions.
AggregateFnVTable
Defines the interface for aggregate function vtables.
AggregateFnVTableExt
Factory functions for aggregate vtables.
DynAccumulator
A trait object for type-erased accumulators, used for dynamic dispatch when the aggregate function is not known at compile time.
DynGroupedAccumulator
A trait object for type-erased grouped accumulators, used for dynamic dispatch when the aggregate function is not known at compile time.

Type Aliases

AccumulatorRef
Reference-counted type-erased accumulator.
AggregateFnId
A unique identifier for an aggregate function.
AggregateFnPluginRef
Reference-counted pointer to an aggregate function plugin.
GroupedAccumulatorRef
Reference-counted type-erased grouped accumulator.