Module combined

Module combined 

Generic adapter for aggregates whose result is computed from two child aggregate functions, e.g. Mean = Sum / Count.

Structs

Combined
Adapter that exposes any BinaryCombined as an AggregateFnVTable.
PairOptions
Pair of options for the two children of a BinaryCombined aggregate.

Traits

BinaryCombined
Declare an aggregate function in terms of two child aggregates.

Type Aliases

CombinedOptions
Combined options for a BinaryCombined aggregate.