Module primitive

Module primitive 

Constants

IS_CONST_LANE_WIDTH

Functions

compute_is_constant
Assumes any floating point has been cast into its bit representation for which != and !is_eq are the same Assumes there’s at least 1 value in the slice, which is an invariant of the entry level function.