Mean

Struct Mean 

pub struct Mean;
Compute the arithmetic mean of an array.

Implemented as Sum / Count via BinaryCombined.

Coercion / return type:

  • Booleans and primitive numeric types are coerced to f64 and the result is a nullable f64.
  • Decimals are kept as decimals but not implemented currently

Implementations

Source

impl Mean

pub fn combined() -> Combined<Self>