pub fn sum_v2(array: &ArrayRef, ctx: &mut ExecutionCtx) -> VortexResult<Scalar>Expand description
Return the SQL-style sum of an array.
Unlike sum, this returns null when the array has no
valid values.
pub fn sum_v2(array: &ArrayRef, ctx: &mut ExecutionCtx) -> VortexResult<Scalar>Return the SQL-style sum of an array.
Unlike sum, this returns null when the array has no
valid values.