Module decimal

Module decimal 

Structs

Decimal
DecimalData
A decimal array that stores fixed-precision decimal numbers with configurable scale.
DecimalDataParts
DecimalMaskedValidityRule
Rule to push down validity masking from MaskedArray parent into DecimalArray child.
DecimalSlots

Traits

DecimalArrayExt
DecimalArraySlotsExt
Typed array accessors for Decimal.

Functions

converted_buffer
Return the array’s unscaled values converted to exactly W, whatever the array’s storage type. Zero-copy when the array is already stored at W.
narrowed_decimal
Attempt to narrow the decimal array to any smaller supported type.

Type Aliases

DecimalArray
A Decimal-encoded Vortex array.