pub struct DictData { /* private fields */ }Implementations
Sourceimpl DictData
impl DictData
Sourcepub unsafe fn new_unchecked() -> Self
pub unsafe fn new_unchecked() -> Self
Build a new DictArray without validating the codes or values.
Safety
This should be called only when you can guarantee the invariants checked
by the safe DictArray::try_new constructor are valid, for example when
you are filtering or slicing an existing valid DictArray.
Sourcepub unsafe fn set_all_values_referenced(
self,
all_values_referenced: bool,
) -> Self
pub unsafe fn set_all_values_referenced( self, all_values_referenced: bool, ) -> Self
Set whether all dictionary values are definitely referenced.
Safety
The caller must ensure that when setting all_values_referenced = true, ALL dictionary
values are actually referenced by at least one valid code. Setting this incorrectly can
lead to incorrect query results in operations like min/max.
This is typically only set to true during dictionary encoding when we know for certain
that all values are referenced.