use_experimental_patches

Function use_experimental_patches 

pub fn use_experimental_patches() -> bool
Flag indicating if experimental patched array support is enabled.

This is set using the environment variable VORTEX_EXPERIMENTAL_PATCHED_ARRAY.

When this is true, any arrays with interior Patches will be read as a Patched array, and eliminate the interior patches.

The builtin compressor will also generate Patched arrays.