pub struct PatchedSlots {
pub inner: ArrayRef,
pub lane_offsets: ArrayRef,
pub patch_indices: ArrayRef,
pub patch_values: ArrayRef,
}Fields
inner: ArrayRefThe inner array containing the base unpatched values.
lane_offsets: ArrayRefThe lane offsets array for locating patches within lanes.
patch_indices: ArrayRefThe indices of patched (exception) values.
patch_values: ArrayRefThe patched (exception) values at the corresponding indices.
Implementations
Sourceimpl PatchedSlots
impl PatchedSlots
Sourcepub const LANE_OFFSETS: usize = 1usize
pub const LANE_OFFSETS: usize = 1usize
Slot index for lane_offsets.
Sourcepub const PATCH_INDICES: usize = 2usize
pub const PATCH_INDICES: usize = 2usize
Slot index for patch_indices.
Sourcepub const PATCH_VALUES: usize = 3usize
pub const PATCH_VALUES: usize = 3usize
Slot index for patch_values.
Sourcepub fn from_slots(slots: Vec<Option<ArrayRef>>) -> Self
pub fn from_slots(slots: Vec<Option<ArrayRef>>) -> Self
Convert owned slot storage into an owned slot struct.
Sourcepub fn into_slots(self) -> Vec<Option<ArrayRef>>
pub fn into_slots(self) -> Vec<Option<ArrayRef>>
Convert this slot struct into storage order.