Module primitive

Module primitive 

Structs

NativeValue
NativeValue serves as a wrapper type to allow us to implement Hash, Eq and other traits on all primitive types.
Primitive
PrimitiveData
A primitive array that stores native types in a contiguous buffer of memory, along with an optional validity child.
PrimitiveDataParts
PrimitiveMaskedValidityRule
Rule to push down validity masking from MaskedArray parent into PrimitiveArray child.
PrimitiveSlots

Traits

PrimitiveArrayExt
PrimitiveArraySlotsExt
Typed array accessors for Primitive.

Functions

chunk_range
Computes the index range for a chunk, accounting for slice offset.
patch_chunk
Patches a chunk of decoded values.

Type Aliases

PrimitiveArray
A Primitive-encoded Vortex array.