pub struct PrimitiveData { /* private fields */ }Expand description
A primitive array that stores native types in a contiguous buffer of memory, along with an optional validity child.
This mirrors the Apache Arrow Primitive layout and can be converted into and out of one without allocations or copies.
The underlying buffer must be natively aligned to the primitive type they are representing.
Values are stored in their native representation with proper alignment. Null values still occupy space in the buffer but are marked invalid in the validity mask.
Examples
use vortex_array::arrays::PrimitiveArray;
// Create from iterator using FromIterator impl
let array: PrimitiveArray = [1i32, 2, 3, 4, 5].into_iter().collect();
// Slice the array
let sliced = array.slice(1..3)?;
// Access individual values
let value = sliced.scalar_at(0).unwrap();
assert_eq!(value, 2i32.into());
Implementations
Sourceimpl PrimitiveData
impl PrimitiveData
Sourcepub fn as_slice<T: NativePType>(&self) -> &[T]
pub fn as_slice<T: NativePType>(&self) -> &[T]
Return a slice of the array’s buffer.
NOTE: these values may be nonsense if the validity buffer indicates that the value is null.
Panic
This operation will panic if the array is not backed by host memory.
Sourceimpl PrimitiveData
impl PrimitiveData
Sourcepub unsafe fn new_unchecked_from_handle(
handle: BufferHandle,
ptype: PType,
_validity: Validity,
) -> Self
pub unsafe fn new_unchecked_from_handle( handle: BufferHandle, ptype: PType, _validity: Validity, ) -> Self
Create a new array from a buffer handle.
Safety
Should ensure that the provided BufferHandle points at sufficiently large region of aligned
memory to hold the ptype values.
Sourcepub fn new<T: NativePType>(
buffer: impl Into<Buffer<T>>,
validity: Validity,
) -> Self
pub fn new<T: NativePType>( buffer: impl Into<Buffer<T>>, validity: Validity, ) -> Self
Creates a new PrimitiveArray.
Panics
Panics if the provided components do not satisfy the invariants documented
in PrimitiveArray::new_unchecked.
Sourcepub fn try_new<T: NativePType>(
buffer: Buffer<T>,
validity: Validity,
) -> VortexResult<Self>
pub fn try_new<T: NativePType>( buffer: Buffer<T>, validity: Validity, ) -> VortexResult<Self>
Constructs a new PrimitiveArray.
See PrimitiveArray::new_unchecked for more information.
Errors
Returns an error if the provided components do not satisfy the invariants documented in
PrimitiveArray::new_unchecked.
Sourcepub unsafe fn new_unchecked<T: NativePType>(
buffer: Buffer<T>,
_validity: Validity,
) -> Self
pub unsafe fn new_unchecked<T: NativePType>( buffer: Buffer<T>, _validity: Validity, ) -> Self
Creates a new PrimitiveArray without validation from these components:
bufferis a typed buffer containing the primitive values.validityholds the null values.
Safety
The caller must ensure all of the following invariants are satisfied:
Validity Requirements
- If
validityisValidity::Array, its length must exactly equalbuffer.len().
Sourcepub fn validate<T: NativePType>(
buffer: &Buffer<T>,
validity: &Validity,
) -> VortexResult<()>
pub fn validate<T: NativePType>( buffer: &Buffer<T>, validity: &Validity, ) -> VortexResult<()>
Validates the components that would be used to create a PrimitiveArray.
This function checks all the invariants required by PrimitiveArray::new_unchecked.
pub fn empty<T: NativePType>(nullability: Nullability) -> Self
Sourceimpl PrimitiveData
impl PrimitiveData
pub fn len(&self) -> usize
pub fn ptype(&self) -> PType
Sourcepub fn buffer_handle(&self) -> &BufferHandle
pub fn buffer_handle(&self) -> &BufferHandle
Get access to the buffer handle backing the array.
pub fn from_buffer_handle( handle: BufferHandle, ptype: PType, _validity: Validity, ) -> Self
pub fn from_byte_buffer( buffer: ByteBuffer, ptype: PType, validity: Validity, ) -> Self
Sourcepub fn from_values_byte_buffer(
valid_elems_buffer: ByteBuffer,
ptype: PType,
validity: Validity,
n_rows: usize,
) -> Self
pub fn from_values_byte_buffer( valid_elems_buffer: ByteBuffer, ptype: PType, validity: Validity, n_rows: usize, ) -> Self
Create a PrimitiveArray from a byte buffer containing only the valid elements.
Sourcepub fn to_buffer<T: NativePType>(&self) -> Buffer<T>
pub fn to_buffer<T: NativePType>(&self) -> Buffer<T>
Get a buffer in host memory holding all the values.
NOTE: some values may be nonsense if the validity buffer indicates that the value is null.
Sourcepub fn into_buffer<T: NativePType>(self) -> Buffer<T>
pub fn into_buffer<T: NativePType>(self) -> Buffer<T>
Consume the array and get a host Buffer containing the data values.
Sourcepub fn into_buffer_mut<T: NativePType>(self) -> BufferMut<T>
pub fn into_buffer_mut<T: NativePType>(self) -> BufferMut<T>
Extract a mutable buffer from the PrimitiveData. Attempts to do this with zero-copy if the buffer is uniquely owned, otherwise will make a copy.
Sourcepub fn try_into_buffer_mut<T: NativePType>(
self,
) -> Result<BufferMut<T>, Buffer<T>>
pub fn try_into_buffer_mut<T: NativePType>( self, ) -> Result<BufferMut<T>, Buffer<T>>
Try to extract a mutable buffer from the PrimitiveData with zero copy.