pub struct ScalarFnArrayView<'a, F: ScalarFnVTable> {
pub vtable: &'a F,
pub options: &'a F::Options,
/* private fields */
}Fields
vtable: &'a Foptions: &'a F::OptionsMethods from Deref<Target = ArrayRef>
Sourcepub fn encoding_id(&self) -> ArrayId
pub fn encoding_id(&self) -> ArrayId
Returns the encoding ID of the array.
Sourcepub fn slice(&self, range: Range<usize>) -> VortexResult<ArrayRef>
pub fn slice(&self, range: Range<usize>) -> VortexResult<ArrayRef>
Performs a constant-time slice of the array.
Sourcepub fn filter(&self, mask: Mask) -> VortexResult<ArrayRef>
pub fn filter(&self, mask: Mask) -> VortexResult<ArrayRef>
Wraps the array in a FilterArray such that it is logically filtered by the given mask.
Sourcepub fn take(&self, indices: ArrayRef) -> VortexResult<ArrayRef>
pub fn take(&self, indices: ArrayRef) -> VortexResult<ArrayRef>
Wraps the array in a DictArray such that it is logically taken by the given indices.
Sourcepub fn scalar_at(&self, index: usize) -> VortexResult<Scalar>
pub fn scalar_at(&self, index: usize) -> VortexResult<Scalar>
Fetch the scalar at the given index.
Sourcepub fn is_valid(&self, index: usize) -> VortexResult<bool>
pub fn is_valid(&self, index: usize) -> VortexResult<bool>
Returns whether the item at index is valid.
Sourcepub fn is_invalid(&self, index: usize) -> VortexResult<bool>
pub fn is_invalid(&self, index: usize) -> VortexResult<bool>
Returns whether the item at index is invalid.
Sourcepub fn all_valid(&self) -> VortexResult<bool>
pub fn all_valid(&self) -> VortexResult<bool>
Returns whether all items in the array are valid.
Sourcepub fn all_invalid(&self) -> VortexResult<bool>
pub fn all_invalid(&self) -> VortexResult<bool>
Returns whether the array is all invalid.
Sourcepub fn valid_count(&self) -> VortexResult<usize>
pub fn valid_count(&self) -> VortexResult<usize>
Returns the number of valid elements in the array.
Sourcepub fn invalid_count(&self) -> VortexResult<usize>
pub fn invalid_count(&self) -> VortexResult<usize>
Returns the number of invalid elements in the array.
Sourcepub fn validity(&self) -> VortexResult<Validity>
pub fn validity(&self) -> VortexResult<Validity>
Returns the Validity of the array.
Sourcepub fn validity_mask(&self) -> VortexResult<Mask>
pub fn validity_mask(&self) -> VortexResult<Mask>
Returns the canonical validity mask for the array.
Sourcepub fn to_canonical(&self) -> VortexResult<Canonical>
pub fn to_canonical(&self) -> VortexResult<Canonical>
Returns the canonical representation of the array.
Sourcepub fn append_to_builder(
&self,
builder: &mut dyn ArrayBuilder,
ctx: &mut ExecutionCtx,
) -> VortexResult<()>
pub fn append_to_builder( &self, builder: &mut dyn ArrayBuilder, ctx: &mut ExecutionCtx, ) -> VortexResult<()>
Writes the array into the canonical builder.
Sourcepub fn statistics(&self) -> StatsSetRef<'_>
pub fn statistics(&self) -> StatsSetRef<'_>
Returns the statistics of the array.
Sourcepub fn as_opt<M: Matcher>(&self) -> Option<M::Match<'_>>
pub fn as_opt<M: Matcher>(&self) -> Option<M::Match<'_>>
Returns the array downcast by the given matcher.
Sourcepub fn as_typed<V: VTable>(&self) -> Option<ArrayView<'_, V>>
pub fn as_typed<V: VTable>(&self) -> Option<ArrayView<'_, V>>
Returns a reference to the typed ArrayInner<V> if this array matches the given vtable type.
Sourcepub fn as_constant(&self) -> Option<Scalar>
pub fn as_constant(&self) -> Option<Scalar>
Returns the constant scalar if this is a constant array.
Sourcepub fn nbytes(&self) -> u64
pub fn nbytes(&self) -> u64
Total size of the array in bytes, including all children and buffers.
Sourcepub fn is_canonical(&self) -> bool
pub fn is_canonical(&self) -> bool
Whether the array is of a canonical encoding.
pub fn reduce(&self) -> VortexResult<Option<ArrayRef>>
pub fn reduce_parent( &self, parent: &ArrayRef, child_idx: usize, ) -> VortexResult<Option<ArrayRef>>
pub fn execute_parent( &self, parent: &ArrayRef, child_idx: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Option<ArrayRef>>
Sourcepub fn nth_child(&self, idx: usize) -> Option<ArrayRef>
pub fn nth_child(&self, idx: usize) -> Option<ArrayRef>
Returns the nth child of the array without allocating a Vec.
Sourcepub fn children_names(&self) -> Vec<String>
pub fn children_names(&self) -> Vec<String>
Returns the names of the children of the array.
Sourcepub fn named_children(&self) -> Vec<(String, ArrayRef)>
pub fn named_children(&self) -> Vec<(String, ArrayRef)>
Returns the array’s children with their names.
Sourcepub fn buffers(&self) -> Vec<ByteBuffer> ⓘ
pub fn buffers(&self) -> Vec<ByteBuffer> ⓘ
Returns the data buffers of the array.
Sourcepub fn buffer_handles(&self) -> Vec<BufferHandle>
pub fn buffer_handles(&self) -> Vec<BufferHandle>
Returns the buffer handles of the array.
Sourcepub fn buffer_names(&self) -> Vec<String>
pub fn buffer_names(&self) -> Vec<String>
Returns the names of the buffers of the array.
Sourcepub fn named_buffers(&self) -> Vec<(String, BufferHandle)>
pub fn named_buffers(&self) -> Vec<(String, BufferHandle)>
Returns the array’s buffers with their names.
Sourcepub fn metadata(&self, session: &VortexSession) -> VortexResult<Option<Vec<u8>>>
pub fn metadata(&self, session: &VortexSession) -> VortexResult<Option<Vec<u8>>>
Returns the serialized metadata of the array.
Sourcepub fn metadata_fmt(&self, f: &mut Formatter<'_>) -> Result
pub fn metadata_fmt(&self, f: &mut Formatter<'_>) -> Result
Formats a human-readable metadata description.
Sourcepub fn nbuffers_recursive(&self) -> usize
pub fn nbuffers_recursive(&self) -> usize
Count the number of buffers encoded by self and all child arrays.
Sourcepub fn depth_first_traversal(&self) -> DepthFirstArrayIterator ⓘ
pub fn depth_first_traversal(&self) -> DepthFirstArrayIterator ⓘ
Depth-first traversal of the array and its children.
Sourcepub fn display_values(&self) -> impl Display
pub fn display_values(&self) -> impl Display
Display logical values of the array
For example, an i16 typed array containing the first five non-negative integers is displayed
as: [0i16, 1i16, 2i16, 3i16, 4i16].
Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
assert_eq!(
format!("{}", array.display_values()),
"[0i16, 1i16, 2i16, 3i16, 4i16]",
)See also: Array::display_as, DisplayArrayAs, and DisplayOptions.
Sourcepub fn display_as(&self, options: DisplayOptions) -> impl Display
pub fn display_as(&self, options: DisplayOptions) -> impl Display
Display the array as specified by the options.
See DisplayOptions for examples.
Sourcepub fn display_tree_encodings_only(&self) -> TreeDisplay
pub fn display_tree_encodings_only(&self) -> TreeDisplay
Display the tree of array encodings and lengths without metadata, buffers, or stats.
Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5)\n";
assert_eq!(format!("{}", array.display_tree_encodings_only()), expected);
let array = StructArray::from_fields(&[
("x", buffer![1, 2].into_array()),
("y", buffer![3, 4].into_array()),
]).unwrap().into_array();
let expected = "root: vortex.struct({x=i32, y=i32}, len=2)
x: vortex.primitive(i32, len=2)
y: vortex.primitive(i32, len=2)
";
assert_eq!(format!("{}", array.display_tree_encodings_only()), expected);Sourcepub fn display_tree(&self) -> TreeDisplay
pub fn display_tree(&self) -> TreeDisplay
Display the tree of encodings of this array as an indented lists.
While some metadata (such as length, bytes and validity-rate) are included, the logical values of the array are not displayed. To view the logical values see Array::display_as and DisplayOptions.
Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)
metadata: ptype: i16
buffer: values host 10 B (align=2) (100.00%)
";
assert_eq!(format!("{}", array.display_tree()), expected);Sourcepub fn tree_display(&self) -> TreeDisplay
pub fn tree_display(&self) -> TreeDisplay
Create a tree display with all built-in extractors (nbytes, stats, metadata, buffers).
This is the default, fully-detailed tree display. Use
tree_display_builder() for a blank slate.
Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)
metadata: ptype: i16
buffer: values host 10 B (align=2) (100.00%)
";
assert_eq!(array.tree_display().to_string(), expected);Sourcepub fn tree_display_builder(&self) -> TreeDisplay
pub fn tree_display_builder(&self) -> TreeDisplay
Create a composable tree display builder with no extractors.
With no extractors, only the node names are shown.
Add extractors with .with() to include additional information.
Most builders should start with EncodingSummaryExtractor to include encoding headers.
Examples
use vortex_array::display::{EncodingSummaryExtractor, NbytesExtractor, MetadataExtractor, BufferExtractor};
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
// Encodings only
let encodings = array.tree_display_builder()
.with(EncodingSummaryExtractor)
.to_string();
assert_eq!(encodings, "root: vortex.primitive(i16, len=5)\n");
// With encoding + nbytes
let with_nbytes = array.tree_display_builder()
.with(EncodingSummaryExtractor)
.with(NbytesExtractor)
.to_string();
assert_eq!(with_nbytes, "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)\n");
// With encoding, metadata, and buffers
let detailed = array.tree_display_builder()
.with(EncodingSummaryExtractor)
.with(MetadataExtractor)
.with(BufferExtractor { show_percent: false })
.to_string();
let expected = "root: vortex.primitive(i16, len=5)\n metadata: ptype: i16\n buffer: values host 10 B (align=2)\n";
assert_eq!(detailed, expected);Sourcepub fn display_table(&self) -> impl Display
pub fn display_table(&self) -> impl Display
Display the array as a formatted table.
For struct arrays, displays a column for each field in the struct. For regular arrays, displays a single column with values.
Examples
let s = StructArray::from_fields(&[
("x", buffer![1, 2].into_array()),
("y", buffer![3, 4].into_array()),
]).unwrap().into_array();
let expected = "
┌──────┬──────┐
│ x │ y │
├──────┼──────┤
│ 1i32 │ 3i32 │
├──────┼──────┤
│ 2i32 │ 4i32 │
└──────┴──────┘".trim();
assert_eq!(format!("{}", s.display_table()), expected);Sourcepub fn to_array_iterator(&self) -> impl ArrayIterator + 'static
pub fn to_array_iterator(&self) -> impl ArrayIterator + 'static
Create an ArrayIterator over the array.
Sourcepub fn serialize(
&self,
ctx: &ArrayContext,
session: &VortexSession,
options: &SerializeOptions,
) -> VortexResult<Vec<ByteBuffer>>
pub fn serialize( &self, ctx: &ArrayContext, session: &VortexSession, options: &SerializeOptions, ) -> VortexResult<Vec<ByteBuffer>>
Serialize the array into a sequence of byte buffers that should be written contiguously. This function returns a vec to avoid copying data buffers.
Optionally, padding can be included to guarantee buffer alignment and ensure zero-copy reads within the context of an external file or stream. In this case, the alignment of the first byte buffer should be respected when writing the buffers to the stream or file.
The format of this blob is a sequence of data buffers, possible with prefixed padding,
followed by a flatbuffer containing an fba::Array message, and ending with a
little-endian u32 describing the length of the flatbuffer message.
Sourcepub fn to_array_stream(&self) -> impl ArrayStream + 'static
pub fn to_array_stream(&self) -> impl ArrayStream + 'static
Create an ArrayStream over the array.
Sourcepub fn as_null_typed(&self) -> NullTyped<'_>
pub fn as_null_typed(&self) -> NullTyped<'_>
Downcasts the array for null-specific behavior.
Sourcepub fn as_bool_typed(&self) -> BoolTyped<'_>
pub fn as_bool_typed(&self) -> BoolTyped<'_>
Downcasts the array for bool-specific behavior.
Sourcepub fn as_primitive_typed(&self) -> PrimitiveTyped<'_>
pub fn as_primitive_typed(&self) -> PrimitiveTyped<'_>
Downcasts the array for primitive-specific behavior.
Sourcepub fn as_decimal_typed(&self) -> DecimalTyped<'_>
pub fn as_decimal_typed(&self) -> DecimalTyped<'_>
Downcasts the array for decimal-specific behavior.
Sourcepub fn as_utf8_typed(&self) -> Utf8Typed<'_>
pub fn as_utf8_typed(&self) -> Utf8Typed<'_>
Downcasts the array for utf8-specific behavior.
Sourcepub fn as_binary_typed(&self) -> BinaryTyped<'_>
pub fn as_binary_typed(&self) -> BinaryTyped<'_>
Downcasts the array for binary-specific behavior.
Sourcepub fn as_struct_typed(&self) -> StructTyped<'_>
pub fn as_struct_typed(&self) -> StructTyped<'_>
Downcasts the array for struct-specific behavior.
Sourcepub fn as_list_typed(&self) -> ListTyped<'_>
pub fn as_list_typed(&self) -> ListTyped<'_>
Downcasts the array for list-specific behavior.
Sourcepub fn as_extension_typed(&self) -> ExtensionTyped<'_>
pub fn as_extension_typed(&self) -> ExtensionTyped<'_>
Downcasts the array for extension-specific behavior.
pub fn try_to_mask_fill_null_false( &self, ctx: &mut ExecutionCtx, ) -> VortexResult<Mask>