Module slice

Module slice 

Reduce and execute adaptors for slice operations.

Encodings that know how to slice themselves implement SliceReduce (metadata-only) or SliceKernel (buffer-reading). The adaptors SliceReduceAdaptor and SliceExecuteAdaptor bridge these into the execution model as ArrayParentReduceRule and ExecuteParentKernel respectively.

Structs

Slice
SliceArray
SliceArrayParts
SliceExecuteAdaptor
Adaptor that wraps a SliceKernel impl as an ExecuteParentKernel.
SliceMetadata
SliceReduceAdaptor
Adaptor that wraps a SliceReduce impl as an ArrayParentReduceRule.

Traits

SliceKernel
SliceReduce