pub struct VarBinData { /* private fields */ }Implementations
Sourceimpl VarBinData
impl VarBinData
Sourcepub fn build(
offsets: ArrayRef,
bytes: ByteBuffer,
dtype: DType,
validity: Validity,
) -> Self
pub fn build( offsets: ArrayRef, bytes: ByteBuffer, dtype: DType, validity: Validity, ) -> Self
Creates a new VarBinArray.
Panics
Panics if the provided components do not satisfy the invariants documented
in VarBinArray::new_unchecked.
Sourcepub fn build_from_handle(
offset: ArrayRef,
bytes: BufferHandle,
dtype: DType,
validity: Validity,
) -> Self
pub fn build_from_handle( offset: ArrayRef, bytes: BufferHandle, dtype: DType, validity: Validity, ) -> Self
Creates a new VarBinArray.
Panics
Panics if the provided components do not satisfy the invariants documented
in VarBinArray::new_unchecked.
Sourcepub fn try_build(
offsets: ArrayRef,
bytes: ByteBuffer,
dtype: DType,
validity: Validity,
) -> VortexResult<Self>
pub fn try_build( offsets: ArrayRef, bytes: ByteBuffer, dtype: DType, validity: Validity, ) -> VortexResult<Self>
Constructs a new VarBinArray.
See VarBinArray::new_unchecked for more information.
Errors
Returns an error if the provided components do not satisfy the invariants documented in
VarBinArray::new_unchecked.
Sourcepub fn try_build_from_handle(
offsets: ArrayRef,
bytes: BufferHandle,
dtype: DType,
validity: Validity,
) -> VortexResult<Self>
pub fn try_build_from_handle( offsets: ArrayRef, bytes: BufferHandle, dtype: DType, validity: Validity, ) -> VortexResult<Self>
Constructs a new VarBinArray from a BufferHandle of memory that may exist
on the CPU or GPU.
See VarBinArray::new_unchecked for more information.
Errors
Returns an error if the provided components do not satisfy the invariants documented in
VarBinArray::new_unchecked.
Sourcepub unsafe fn new_unchecked(bytes: ByteBuffer) -> Self
pub unsafe fn new_unchecked(bytes: ByteBuffer) -> Self
Creates a new VarBinArray without validation from these components:
offsetsis an array of byte offsets into thebytesbuffer.bytesis a buffer containing all the variable-length data concatenated.dtypespecifies whether this contains UTF-8 strings or binary data.validityholds the null values.
Safety
The caller must ensure all of the following invariants are satisfied:
Offsets Requirements
offsetsmust be a non-nullable integer array.offsetsmust contain at least 1 element (for empty array, it contains [0]).- All values in
offsetsmust be monotonically non-decreasing. - The first value in
offsetsmust be 0. - No offset value may exceed
bytes.len().
Type Requirements
dtypemust be exactlyDType::BinaryorDType::Utf8.- If
dtypeisDType::Utf8, every byte slicebytes[offsets[i]..offsets[i+1]]must be valid UTF-8. dtype.is_nullable()must match the nullability ofvalidity.
Validity Requirements
- If
validityisValidity::Array, its length must exactly equaloffsets.len() - 1.
Sourcepub unsafe fn new_unchecked_from_handle(bytes: BufferHandle) -> Self
pub unsafe fn new_unchecked_from_handle(bytes: BufferHandle) -> Self
Creates a new VarBinArray without validation from its components, with string data
stored in a BufferHandle (CPU or GPU).
Safety
The caller must ensure all the invariants documented in new_unchecked are satisfied.
Sourcepub fn validate(
offsets: &ArrayRef,
bytes: &BufferHandle,
dtype: &DType,
validity: &Validity,
) -> VortexResult<()>
pub fn validate( offsets: &ArrayRef, bytes: &BufferHandle, dtype: &DType, validity: &Validity, ) -> VortexResult<()>
Validates the components that would be used to create a VarBinArray.
This function checks all the invariants required by VarBinArray::new_unchecked.
Sourcepub fn bytes(&self) -> &ByteBuffer
pub fn bytes(&self) -> &ByteBuffer
Access the value bytes child buffer
Note
Bytes child buffer is never sliced when the array is sliced so this can include values
that are not logically present in the array. Users should prefer sliced_bytes
unless they’re resolving values via the offset child array.
Sourcepub fn bytes_handle(&self) -> &BufferHandle
pub fn bytes_handle(&self) -> &BufferHandle
Access the value bytes buffer handle.