Module arrow

Module arrow 

Utilities to work with Arrow data and types.

Modules

bool
byte_view
null
primitive

Structs

ArrowArrayStreamAdapter
An adapter for converting an ArrowArrayStreamReader into a Vortex ArrayStream.
ArrowSession
Session-scoped registry of Arrow extension plugins.
Datum
A wrapper around a generic Arrow array that can be used as a Datum in Arrow compute.

Enums

ArrowExport
Outcome of a successful call to ArrowExportVTable::execute_arrow.
ArrowImport
Outcome of a successful call to ArrowImportVTable::from_arrow_array.

Traits

ArrowArrayExecutorDeprecated
Trait for executing a Vortex array to produce an Arrow array.
ArrowExportVTable
Plugin layer for exporting a Vortex array to an Arrow extension type.
ArrowImportVTable
Plugin layer for importing an Arrow extension-typed array into a Vortex extension array.
ArrowSessionExt
Extension trait for accessing the ArrowSession on a Vortex session.
FromArrowArray
IntoArrowArrayDeprecated

Functions

from_arrow_array_with_len
Convert an Arrow array to an Array with a specific length. This is useful for compute functions that delegate to Arrow using Datum, which will return a scalar (length 1 Arrow array) if the input array is constant.
to_arrow_null_buffer
Converts a Validity to an Arrow NullBuffer, executing the validity array if needed.
to_null_buffer
Converts a mask to a null buffer.

Type Aliases

ArrowExportVTableRef
ArrowImportVTableRef