from_arrow_columnar

Function from_arrow_columnar 

pub fn from_arrow_columnar<A>(
    array: A,
    len: usize,
    nullable: bool,
    ctx: &mut ExecutionCtx,
) -> VortexResult<ArrayRef>
Convert an Arrow array to an Array with a specific length, using the provided ExecutionCtx.

This is useful for compute functions that delegate to Arrow using Datum, which will return a scalar (length 1 Arrow array) if the input array is constant.

Error

The provided array must have length len or 1.