DeviceBuffer

Trait DeviceBuffer 

pub trait DeviceBuffer:
    'static
    + Send
    + Sync
    + Debug
    + DynEq
    + DynHash {
    // Required methods
    fn as_any(&self) -> &dyn Any;
    fn len(&self) -> usize;
    fn alignment(&self) -> Alignment;
    fn copy_to_host_sync(
        &self,
        alignment: Alignment,
    ) -> VortexResult<ByteBuffer>;
    fn copy_to_host(
        &self,
        alignment: Alignment,
    ) -> VortexResult<BoxFuture<'static, VortexResult<ByteBuffer>>>;
    fn slice(&self, range: Range<usize>) -> Arc<dyn DeviceBuffer> ;
    fn aligned(
        self: Arc<Self>,
        alignment: Alignment,
    ) -> VortexResult<Arc<dyn DeviceBuffer>>;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
A buffer that is stored on the GPU.

Required Methods

fn as_any(&self) -> &dyn Any

Returns a reference as Any to enable downcasting.

fn len(&self) -> usize

Returns the length of the buffer in bytes.

fn alignment(&self) -> Alignment

Returns the alignment of the buffer.

fn copy_to_host_sync(&self, alignment: Alignment) -> VortexResult<ByteBuffer>

Attempts to copy the device buffer to a host ByteBuffer.

Errors

This operation may fail, depending on the device implementation and the underlying hardware.

fn copy_to_host( &self, alignment: Alignment, ) -> VortexResult<BoxFuture<'static, VortexResult<ByteBuffer>>>

Copies the device buffer to a host buffer asynchronously.

Schedules an async copy and returns a future that completes when the copy is finished.

Arguments
  • alignment - The memory alignment to use for the host buffer.
Errors

Returns an error if the async copy operation fails.

fn slice(&self, range: Range<usize>) -> Arc<dyn DeviceBuffer>

Create a new buffer that references a subrange of this buffer at the given slice indices.

Note that slice indices are in byte units.

fn aligned( self: Arc<Self>, alignment: Alignment, ) -> VortexResult<Arc<dyn DeviceBuffer>>

Return a buffer with the given alignment. Where possible, this will be zero-copy.

Errors

Returns an error if the buffer cannot be aligned (e.g., allocation or copy failure).

Provided Methods

fn is_empty(&self) -> bool

Returns true if the buffer is empty.