Module compute

Module compute 

Compute kernels on top of Vortex Arrays.

We aim to provide a basic set of compute kernels that can be used to efficiently index, slice, and filter Vortex Arrays in their encoded forms.

Every array encoding has the ability to implement their own efficient implementations of these operators, else we will decode, and perform the equivalent operator from Arrow.

Re-exports

pub use crate::aggregate_fn::fns::min_max::MinMaxResult;

Modules

conformance

Structs

BinaryArgs
For binary compute functions, it’s useful to just have this short-cut.
ComputeFn
An instance of a compute function holding the implementation vtable and a set of registered compute kernels.
InvocationArgs
Arguments to a compute function invocation.
IsConstantOpts
Configuration for is_constant_opts operations.
UnaryArgs
For unary compute functions, it’s useful to just have this short-cut.

Enums

Cost
When calling is_constant the children are all checked for constantness. This enum decide at each precision/cost level the constant check should run as. The cost increase as we move down the list.
Input
Input to a compute function.
Output
Output from a compute function.

Traits

ComputeFnVTable
VTable for the implementation of a compute function.
Kernel
Compute functions can ask arrays for compute kernels for a given invocation.
Options
Options for a compute function invocation.

Functions

is_constantDeprecated
Computes whether an array has constant values.
is_constant_optsDeprecated
Computes whether an array has constant values.
is_sortedDeprecated
Computes whether an array is sorted in non-decreasing order.
is_strict_sortedDeprecated
Computes whether an array is strictly sorted in increasing order.
min_maxDeprecated
nan_countDeprecated
sumDeprecated