pub fn test_mask_conformance(array: &ArrayRef, ctx: &mut ExecutionCtx)Expand description
Test mask compute function with various array sizes and patterns. The mask operation sets elements to null where the mask is true.
pub fn test_mask_conformance(array: &ArrayRef, ctx: &mut ExecutionCtx)Test mask compute function with various array sizes and patterns. The mask operation sets elements to null where the mask is true.