mask

Function mask 

pub fn mask(array: &dyn Array, mask: &Mask) -> VortexResult<ArrayRef>
👎Deprecated: use array.mask(mask_array) via ArrayBuiltins instead
Replace values with null where the mask is true.

The returned array is nullable but otherwise has the same dtype and length as array.

This function returns a lazy ScalarFnArray wrapping the Mask expression that defers the actual masking operation until execution time. The mask is inverted (true=mask-out becomes true=keep) and passed as a boolean child to the expression.