Module display

Module display 

Structs

BufferExtractor
Extractor that adds buffer detail lines.
DisplayArrayAs
A shim used to display an array as specified in the options.
EncodingSummaryExtractor
Extractor that adds the encoding summary (e.g. vortex.primitive(i16, len=5)) to the header.
IndentedFormatter
Access to a formatter together with the indentation for detail lines.
MetadataExtractor
Extractor that adds a metadata: ... detail line.
NbytesExtractor
Extractor that adds nbytes=X (Y%) to the header line.
StatsExtractor
Extractor that adds stats annotations (e.g. [nulls=3, min=5]) to the header line.
TreeContext
Context threaded through tree traversal for percentage calculations etc.
TreeDisplay
Composable tree display builder.

Enums

DisplayOptions
Describe how to convert an array to a string.

Traits

TreeExtractor
Contributes one composable dimension of information to tree nodes.