#[repr(u8)]pub enum DecimalType {
I8 = 0,
I16 = 1,
I32 = 2,
I64 = 3,
I128 = 4,
I256 = 5,
}Expand description
Type of the decimal values.
This is used for other crates to understand the different underlying representations possible for decimals.
Variants
I8 = 0
8-bit decimal value type.
I16 = 1
16-bit decimal value type.
I32 = 2
32-bit decimal value type.
I64 = 3
64-bit decimal value type.
I128 = 4
128-bit decimal value type.
I256 = 5
256-bit decimal value type.
Implementations
Sourceimpl DecimalType
impl DecimalType
Sourceimpl DecimalType
impl DecimalType
Sourcepub fn smallest_decimal_value_type(decimal_dtype: &DecimalDType) -> DecimalType
pub fn smallest_decimal_value_type(decimal_dtype: &DecimalDType) -> DecimalType
Maps a DecimalDType (precision) into the smallest DecimalType that can represent it.
Sourcepub fn byte_width(&self) -> usize
pub fn byte_width(&self) -> usize
Returns the size in bytes of the underlying native type for this decimal type.
Sourcepub fn is_compatible_decimal_value_type(self, dtype: DecimalDType) -> bool
pub fn is_compatible_decimal_value_type(self, dtype: DecimalDType) -> bool
True if Self can represent every value of the type DecimalDType.