PType

Enum PType 

#[repr(u8)]
pub enum PType { U8 = 0, U16 = 1, U32 = 2, U64 = 3, I8 = 4, I16 = 5, I32 = 6, I64 = 7, F16 = 8, F32 = 9, F64 = 10, }
Physical type enum, represents the in-memory physical layout but might represent a different logical type.

Variants



U8 = 0

An 8-bit unsigned integer



U16 = 1

A 16-bit unsigned integer



U32 = 2

A 32-bit unsigned integer



U64 = 3

A 64-bit unsigned integer



I8 = 4

An 8-bit signed integer



I16 = 5

A 16-bit signed integer



I32 = 6

A 32-bit signed integer



I64 = 7

A 64-bit signed integer



F16 = 8

A 16-bit floating point number



F32 = 9

A 32-bit floating point number



F64 = 10

A 64-bit floating point number

Implementations

Source

impl PType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PType.

pub fn from_i32(value: i32) -> Option<PType>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PType, or None if value is not a valid variant.

Source

impl PType

pub const fn is_unsigned_int(self) -> bool

Returns true iff this PType is an unsigned integer type

pub const fn is_signed_int(self) -> bool

Returns true iff this PType is a signed integer type

pub const fn is_int(self) -> bool

Returns true iff this PType is an integer type Equivalent to self.is_unsigned_int() || self.is_signed_int()

pub const fn is_float(self) -> bool

Returns true iff this PType is a floating point type

pub const fn byte_width(&self) -> usize

Returns the number of bytes in this PType

pub const fn bit_width(&self) -> usize

Returns the number of bits in this PType

pub fn max_value_as_u64(&self) -> u64

Returns the maximum value of this PType if it is an integer type Returns u64::MAX if the value is too large to fit in a u64

pub const fn to_signed(self) -> Self

Returns the PType that corresponds to the signed version of this PType

pub const fn to_unsigned(self) -> Self

Returns the PType that corresponds to the unsigned version of this PType For floating point types, this will simply return self

pub const fn min_unsigned_ptype_for_value(value: u64) -> Self

Returns the minimum unsigned integer PType that can represent the given value.

pub const fn min_signed_ptype_for_value(value: i64) -> Self

Returns the minimum signed integer PType that can represent the given value.

pub const fn max_unsigned_ptype(self, other: Self) -> Self

Returns the wider of two unsigned integer PTypes based on byte width.

pub const fn max_signed_ptype(self, other: Self) -> Self

Returns the wider of two signed integer PTypes based on byte width.