FieldPath

Struct FieldPath 

pub struct FieldPath(/* private fields */);
A sequence of field selectors representing a path through zero or more layers of DType.

Examples

The empty path references the root:

use vortex_array::dtype::*;

let dtype_i32 = DType::Primitive(PType::I32, Nullability::NonNullable);
assert_eq!(dtype_i32, FieldPath::root().resolve(dtype_i32.clone()).unwrap());

Implementations

Source

impl FieldPath

pub fn root() -> Self

The selector for the root (i.e., the top-level struct itself)

pub fn from_name<F: Into<FieldName>>(name: F) -> Self

Constructs a new FieldPath from a single field selector (i.e., a direct child field of the top-level struct)

pub fn parts(&self) -> &[Field]

Returns the sequence of field selectors that make up this path

pub fn is_root(&self) -> bool

Returns whether this path is a root path.

pub fn push<F: Into<Field>>(self, field: F) -> Self

Pushes a new field selector to the end of this path

pub fn starts_with_field(&self, field: &Field) -> bool

Whether the path starts with the given field name TODO(joe): handle asserts better.

pub fn step_into(self) -> Option<Self>

Steps into the next field in the path

pub fn resolve(&self, dtype: DType) -> Option<DType>

The dtype, within the given type, to which this field path refers.

Note that a nullable DType may contain a non-nullable DType. This function returns the literal nullability of the child.

Examples

Extract the type of the “b” field from struct{a: list(struct{b: u32})?}:

use std::sync::Arc;

use vortex_array::dtype::*;
use vortex_array::dtype::Nullability::*;

let dtype = DType::Struct(
    StructFields::from_iter([(
        "a",
        DType::List(
            Arc::new(DType::Struct(
                StructFields::from_iter([(
                    "b",
                    DType::Primitive(PType::U32, NonNullable),
                )]),
                NonNullable,
            )),
            Nullable,
        ),
    )]),
    NonNullable,
);

let path = FieldPath::from(vec![Field::from("a"), Field::ElementType, Field::from("b")]);
let resolved = path.resolve(dtype).unwrap();
assert_eq!(resolved, DType::Primitive(PType::U32, NonNullable));
pub fn exists_in(&self, dtype: DType) -> bool

Does the field referenced by the field path exist in the given dtype?

pub fn overlap(&self, other: &FieldPath) -> bool

Returns true if this path overlaps with another path (i.e., one is a prefix of the other).