pub trait TryFromBytes: Sized {
// Required method
fn try_from_le_bytes(bytes: &[u8]) -> VortexResult<Self>;
}Expand description
A trait for types that can be converted from a little-endian byte slice
Required Methods
Sourcefn try_from_le_bytes(bytes: &[u8]) -> VortexResult<Self>
fn try_from_le_bytes(bytes: &[u8]) -> VortexResult<Self>
Attempts to convert a slice of bytes in little-endian order to this type
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".