Module analysis

Module analysis 

Re-exports

pub use annotation::*;
pub use immediate_access::*;

Modules

annotation
immediate_access

Functions

label_bound_tree
Label each node in a bound expression using identity-keyed lookups.
label_is_fallible
label_strict
Label each expression with whether its entire subtree is strict.
label_tree
Label each node in an expression tree using a bottom-up traversal.
referenced_field_paths
Returns the rooted field paths referenced by an expression.

Type Aliases

BooleanLabels
Boolean labels keyed by each expression node in a tree.
BoundLabels
Labels keyed by bound-tree identity.