Module annotation

Module annotation 

Traits

Annotation
AnnotationFn

Functions

descendent_annotations
Walk the expression tree and annotate each expression with zero or more annotations.
descendent_bound_annotations
Annotate a bound expression and propagate each annotation to its ancestors.
direct_annotations
Walk the expression tree and annotate each expression with zero or more annotations.
direct_bound_annotations
Annotate each bound-expression node without propagating annotations to its ancestors.

Type Aliases

Annotations
BoundAnnotations
Annotations keyed by bound-tree identity.