descendent_annotations

Function descendent_annotations 

pub fn descendent_annotations<'a, N, A>(
    expr: &'a N,
    annotate: A,
) -> Annotations<'a, A::Annotation, N>
where N: Node + Eq + Hash, A: AnnotationFn<N>,
Walk the expression tree and annotate each expression with zero or more annotations.

Returns a map of each expression to all annotations that any of its descendent (child) expressions are annotated with.