descendent_bound_annotations

Function descendent_bound_annotations 

pub fn descendent_bound_annotations<A>(
    expr: &BoundExpression,
    annotate: A,
) -> BoundAnnotations<A::Annotation>
Annotate a bound expression and propagate each annotation to its ancestors.

Unlike descendent_annotations, this uses ExactBoundExpr keys to preserve the cheap identity semantics of an already-bound tree.