label_bound_tree

Function label_bound_tree 

pub fn label_bound_tree<L: Clone>(
    expr: &BoundExpression,
    self_label: impl Fn(&BoundExpression) -> L,
    merge_child: impl FnMut(L, &L) -> L,
) -> BoundLabels<L>
Label each node in a bound expression using identity-keyed lookups.

This avoids structurally hashing bound dtypes, which may deserialize a lazy schema.