label_infallible

Function label_infallible 

pub fn label_infallible(expr: &Expression) -> BooleanLabels<'_>
Label each expression with whether its entire subtree is infallible.

A subtree is infallible only when the node’s scalar function and every child subtree are infallible. See crate::scalar_fn::ScalarFnVTable::is_infallible for the scalar-function contract.