pub fn binary(
operator: Operator,
lhs: BoundExpression,
rhs: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound binary expression with the given operator.
pub fn binary(
operator: Operator,
lhs: BoundExpression,
rhs: BoundExpression,
) -> BoundExpressionCreates a bound binary expression with the given operator.