pub fn col(field: impl Into<FieldName>, scope: DType) -> BoundExpressionExpand description
Creates a bound expression that accesses a field from a root scope with the given dtype.
pub fn col(field: impl Into<FieldName>, scope: DType) -> BoundExpressionCreates a bound expression that accesses a field from a root scope with the given dtype.