pub fn ext_storage(input: BoundExpression) -> BoundExpressionExpand description
Creates a bound expression that extracts an extension array’s storage values.
pub fn ext_storage(input: BoundExpression) -> BoundExpressionCreates a bound expression that extracts an extension array’s storage values.