pub fn fill_null(
child: BoundExpression,
fill_value: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound expression that replaces null values with a fill value.
pub fn fill_null(
child: BoundExpression,
fill_value: BoundExpression,
) -> BoundExpressionCreates a bound expression that replaces null values with a fill value.