pub fn get_item(
field: impl Into<FieldName>,
child: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound expression that extracts a named field from a struct expression.
pub fn get_item(
field: impl Into<FieldName>,
child: BoundExpression,
) -> BoundExpressionCreates a bound expression that extracts a named field from a struct expression.