pub fn list_length(input: BoundExpression) -> BoundExpressionExpand description
Creates a bound expression that computes the number of elements in each list.
pub fn list_length(input: BoundExpression) -> BoundExpressionCreates a bound expression that computes the number of elements in each list.