pub fn list_sum(input: BoundExpression) -> BoundExpressionExpand description
Creates a bound expression that sums the elements of each list.
pub fn list_sum(input: BoundExpression) -> BoundExpressionCreates a bound expression that sums the elements of each list.