pub fn merge_opts(
elements: impl IntoIterator<Item = BoundExpression>,
duplicate_handling: DuplicateHandling,
) -> BoundExpressionExpand description
Creates a bound merge expression with explicit duplicate handling.
pub fn merge_opts(
elements: impl IntoIterator<Item = BoundExpression>,
duplicate_handling: DuplicateHandling,
) -> BoundExpressionCreates a bound merge expression with explicit duplicate handling.