pub fn not(operand: BoundExpression) -> BoundExpressionExpand description
Creates a bound expression that logically inverts boolean values.
pub fn not(operand: BoundExpression) -> BoundExpressionCreates a bound expression that logically inverts boolean values.