pub fn or_collect<I>(iter: I) -> Option<BoundExpression>where
I: IntoIterator<Item = BoundExpression>,Expand description
Collects bound expressions into a balanced tree of boolean OR expressions.
pub fn or_collect<I>(iter: I) -> Option<BoundExpression>where
I: IntoIterator<Item = BoundExpression>,Collects bound expressions into a balanced tree of boolean OR expressions.