pub fn pack(
elements: impl IntoIterator<Item = (impl Into<FieldName>, BoundExpression)>,
nullability: Nullability,
) -> BoundExpressionExpand description
Creates a bound expression that packs values into a struct with named fields.
pub fn pack(
elements: impl IntoIterator<Item = (impl Into<FieldName>, BoundExpression)>,
nullability: Nullability,
) -> BoundExpressionCreates a bound expression that packs values into a struct with named fields.