pub fn root(dtype: DType) -> BoundExpressionExpand description
Creates a bound expression that references a root scope with the given dtype.
pub fn root(dtype: DType) -> BoundExpressionCreates a bound expression that references a root scope with the given dtype.