pub fn select(
field_names: impl Into<FieldNames>,
child: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound expression that selects specific fields from a struct expression.
pub fn select(
field_names: impl Into<FieldNames>,
child: BoundExpression,
) -> BoundExpressionCreates a bound expression that selects specific fields from a struct expression.