pub fn select_exclude(
fields: impl Into<FieldNames>,
child: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound expression that excludes specific fields from a struct expression.
pub fn select_exclude(
fields: impl Into<FieldNames>,
child: BoundExpression,
) -> BoundExpressionCreates a bound expression that excludes specific fields from a struct expression.