pub fn variant_get(
child: BoundExpression,
path: impl Into<VariantPath>,
dtype: Option<DType>,
) -> BoundExpressionExpand description
Creates a bound expression that extracts a path from a Variant expression.
pub fn variant_get(
child: BoundExpression,
path: impl Into<VariantPath>,
dtype: Option<DType>,
) -> BoundExpressionCreates a bound expression that extracts a path from a Variant expression.