pub fn zip_expr(
mask: BoundExpression,
if_true: BoundExpression,
if_false: BoundExpression,
) -> BoundExpressionExpand description
Creates a bound zip expression that conditionally selects between two arrays.
pub fn zip_expr(
mask: BoundExpression,
if_true: BoundExpression,
if_false: BoundExpression,
) -> BoundExpressionCreates a bound zip expression that conditionally selects between two arrays.