pub fn byte_length(input: Expression) -> ExpressionExpand description
Creates an expression that computes the byte length of each element. This is akin to ANSI SQL OCTET_LENGTH(), or DuckDB’s strlen().
let expr = byte_length(root());pub fn byte_length(input: Expression) -> ExpressionCreates an expression that computes the byte length of each element. This is akin to ANSI SQL OCTET_LENGTH(), or DuckDB’s strlen().
let expr = byte_length(root());