variant_get

Function variant_get 

pub fn variant_get(
    child: Expression,
    path: impl Into<VariantPath>,
    dtype: Option<DType>,
) -> Expression
Creates an expression that extracts a path from a Variant expression.

Missing paths, traversal mismatches, and failed casts return null. When dtype is None, results are nullable Variant values; otherwise results are nullable values of dtype.