StatsCatalog

Trait StatsCatalog 

pub trait StatsCatalog {
    // Provided method
    fn stats_ref(
        &self,
        _field_path: &FieldPath,
        _stat: Stat,
    ) -> Option<Expression> { ... }
}
A catalog of available stats that are associated with field paths.

Provided Methods

fn stats_ref(&self, _field_path: &FieldPath, _stat: Stat) -> Option<Expression>

Given a field path and statistic, return an expression that when evaluated over the catalog will return that stat for the referenced field.

This is likely to be a column expression, or a literal.

Returns None if the stat is not available for the field path.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors