Module transform

Module transform 

Structs

BoundPartitionedExpr
The result of partitioning a bound expression.
PartitionedExpr
The result of partitioning an expression.

Functions

coerce_expression
Rewrite an expression tree to insert casts where a scalar function’s coerce_args demands a different type than what the child currently produces.
partition
Partition an expression into sub-expressions that are uniquely associated with an annotation. A root expression is also returned that can be used to recombine the results of the partitions into the result of the original expression.
partition_annotations
partition_bound
Partition an expression into sub-expressions that are uniquely associated with an annotation. A root expression is also returned that can be used to recombine the results of the partitions into the result of the original expression.
partition_bound_annotations
Partition an already-annotated bound expression tree.
replace
Replaces all occurrences of needle in the expression expr with replacement.
replace_root_fields
Expand the root expression with a pack of the given struct fields.