pub struct Timestamp;Expand description
Timestamp DType.
Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn new(time_unit: TimeUnit, nullability: Nullability) -> ExtDType<Self>
pub fn new(time_unit: TimeUnit, nullability: Nullability) -> ExtDType<Self>
Creates a new Timestamp extension =dtype with the given time unit and nullability.
Sourcepub fn new_with_tz(
time_unit: TimeUnit,
timezone: Option<Arc<str>>,
nullability: Nullability,
) -> ExtDType<Self>
pub fn new_with_tz( time_unit: TimeUnit, timezone: Option<Arc<str>>, nullability: Nullability, ) -> ExtDType<Self>
Creates a new Timestamp extension dtype with the given time unit, timezone, and nullability.
Sourcepub fn new_with_options(
options: TimestampOptions,
nullability: Nullability,
) -> ExtDType<Self>
pub fn new_with_options( options: TimestampOptions, nullability: Nullability, ) -> ExtDType<Self>
Creates a new Timestamp extension dtype with the given options and nullability.