BufferAllocatorRef

Struct BufferAllocatorRef 

pub struct BufferAllocatorRef(/* private fields */);
A shared reference to a buffer allocator.

The static allocator does not need shared ownership, so it is stored without an Arc. This makes cloning the common static allocator a simple value copy.

Implementations

Source

impl BufferAllocatorRef

pub fn new(allocator: impl BufferAllocator) -> BufferAllocatorRef

Wrap an allocator in a shared reference.

pub fn statically_allocated() -> BufferAllocatorRef

Return a shared reference to the static allocator.

pub fn static_ref() -> &'static BufferAllocatorRef

Return a borrowed reference to the static allocator.

pub fn ptr_eq(&self, other: &BufferAllocatorRef) -> bool

Returns true if both references point to the same allocator.

pub fn with_capacity<T>(&self, capacity: usize) -> BufferMut<T>

Create a mutable buffer with this allocator.

pub fn with_capacity_aligned<T>( &self, capacity: usize, alignment: Alignment, ) -> BufferMut<T>

Create an aligned mutable buffer with this allocator.

pub fn zeroed<T>(&self, len: usize) -> BufferMut<T>

Create a zeroed mutable buffer with this allocator.

pub fn copy_from<T>(&self, values: impl AsRef<[T]>) -> BufferMut<T>

Copy values into a mutable buffer made by this allocator.