pub struct ArrayKernels { /* private fields */ }Expand description
Session-scoped registry of optimizer kernel functions.
Implementations
Sourceimpl ArrayKernels
impl ArrayKernels
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Create an empty ArrayKernels with no kernels registered.
Sourcepub fn register_reduce_parent<I: IntoIterator<Item = ReduceParentFn>>(
&self,
parent: Id,
child: Id,
fns: I,
)
pub fn register_reduce_parent<I: IntoIterator<Item = ReduceParentFn>>( &self, parent: Id, child: Id, fns: I, )
Register a ReduceParentFn for (outer, child).
The optimizer will invoke f when it sees a parent with encoding id outer holding a
child with encoding id child during a reduce_parent step, before trying the child
encoding’s static PARENT_RULES. outer is usually the parent array’s encoding id. For
ScalarFnArray, it is the scalar function id, for example Cast.id().
Replaces any function already registered for the same pair.
Sourcepub fn find_reduce_parent(
&self,
parent: Id,
child: Id,
) -> Option<Arc<[ReduceParentFn]>>
pub fn find_reduce_parent( &self, parent: Id, child: Id, ) -> Option<Arc<[ReduceParentFn]>>
Look up the ReduceParentFn registered for (outer, child).
Returns an owned Arc so the session-variable borrow can be dropped before invoking the
function.