Module patches

Module patches 

Structs

PatchSlotIndices
Slot indices for the three patch components within a slot array.
Patches
A helper for working with patched arrays.
PatchesData
Metadata stored in an array’s data struct for reconstructing Patches from slots.
PatchesMetadata

Constants

PATCH_CHUNK_SIZE
One patch index offset is stored for each chunk. This allows for constant time patch index lookups.