Module extension

Module extension 

Extension Scalar Values, and interfaces for working with them.

We define normal Scalars as the combination of a ScalarValue and a DType.

Similarly, we define an extension Scalar as the combination of an ExtScalarValueRef and an ExtDTypeRef.

Structs

ExtScalarValue
A typed extension scalar value, parameterized by a concrete ExtVTable.
ExtScalarValueRef
A type-erased extension scalar value.