pub fn compare_nested_arrow_arrays(
lhs: &dyn Array,
rhs: &dyn Array,
operator: CompareOperator,
) -> VortexResult<BooleanArray>Expand description
Compare two Arrow arrays element-wise using make_comparator.
This function is required for nested types (Struct, List, FixedSizeList) because Arrow’s
vectorized comparison kernels (cmp::eq, cmp::neq, etc.) do not support them.
The vectorized kernels are faster but only work on primitive types, so for non-nested types, prefer using the vectorized kernels directly for better performance.