Module fill_null

Module fill_null 

Structs

FillNull
An expression that replaces null values in the input with a fill value.
FillNullExecuteAdaptor
Adaptor that wraps a FillNullKernel impl as an ExecuteParentKernel.
FillNullReduceAdaptor
Adaptor that wraps a FillNullReduce impl as an ArrayParentReduceRule.

Traits

FillNullKernel
Fill nulls in an array with a scalar value, potentially reading buffers.
FillNullReduce
Fill nulls in an array with a scalar value without reading buffers.