Module like

Module like 

Structs

Like
Expression that performs SQL LIKE pattern matching.
LikeExecuteAdaptor
Adaptor that wraps a LikeKernel impl as an ExecuteParentKernel.
LikeOptions
Options for SQL LIKE function
LikeReduceAdaptor
Adaptor that wraps a LikeReduce impl as an ArrayParentReduceRule.

Traits

LikeKernel
Like pattern matching on an array, potentially reading buffers.
LikeReduce
Like pattern matching on an array without reading buffers.