Module operators

Module operators 

Enums

CompareOperator
The six comparison operators, providing compile-time guarantees that only comparison variants are used where comparisons are expected.
Operator
Equalities, inequalities, and boolean operations over possibly null values.