Module zip

Module zip 

Structs

Zip
An expression that conditionally selects between two arrays based on a boolean mask.
ZipExecuteAdaptor
Adaptor that wraps a ZipKernel impl as an ExecuteParentKernel.
ZipReduceAdaptor
Adaptor that wraps a ZipReduce impl as an ArrayParentReduceRule.

Traits

ZipKernel
Zip two arrays using a mask, potentially reading buffers.
ZipReduce
Zip two arrays using a mask without reading buffers.