pub struct ScalarFnRef(/* private fields */);Expand description
A type-erased scalar function, pairing a vtable with bound options behind a trait object.
This stores a ScalarFnVTable and its options behind an Arc<dyn DynScalarFn>, allowing
heterogeneous storage inside Expression and crate::arrays::ScalarFnArray.
Use super::ScalarFn::new() to construct, and super::ScalarFn::erased() to obtain a
ScalarFnRef.
Implementations
Sourceimpl ScalarFnRef
impl ScalarFnRef
Sourcepub fn id(&self) -> ScalarFnId
pub fn id(&self) -> ScalarFnId
Returns the ID of this scalar function.
Sourcepub fn is<V: ScalarFnVTable>(&self) -> bool
pub fn is<V: ScalarFnVTable>(&self) -> bool
Returns whether the scalar function is of the given vtable type.
Sourcepub fn as_opt<V: ScalarFnVTable>(&self) -> Option<&V::Options>
pub fn as_opt<V: ScalarFnVTable>(&self) -> Option<&V::Options>
Returns the typed options for this scalar function if it matches the given vtable type.
Sourcepub fn vtable_ref<V: ScalarFnVTable>(&self) -> Option<&V>
pub fn vtable_ref<V: ScalarFnVTable>(&self) -> Option<&V>
Returns a reference to the typed vtable if it matches the given vtable type.
Sourcepub fn as_<V: ScalarFnVTable>(&self) -> &V::Options
pub fn as_<V: ScalarFnVTable>(&self) -> &V::Options
Returns the typed options for this scalar function if it matches the given vtable type.
Panics
Panics if the vtable type does not match.
Sourcepub fn options(&self) -> ScalarFnOptions<'_>
pub fn options(&self) -> ScalarFnOptions<'_>
The type-erased options for this scalar function.
Sourcepub fn signature(&self) -> ScalarFnSignature<'_>
pub fn signature(&self) -> ScalarFnSignature<'_>
Signature information for this scalar function.
Sourcepub fn return_dtype(&self, arg_types: &[DType]) -> VortexResult<DType>
pub fn return_dtype(&self, arg_types: &[DType]) -> VortexResult<DType>
Compute the return DType of this expression given the input argument types.
Sourcepub fn validity(&self, expr: &Expression) -> VortexResult<Expression>
pub fn validity(&self, expr: &Expression) -> VortexResult<Expression>
Transforms the expression into one representing the validity of this expression.
Sourcepub fn execute(&self, ctx: ExecutionArgs<'_>) -> VortexResult<ArrayRef>
pub fn execute(&self, ctx: ExecutionArgs<'_>) -> VortexResult<ArrayRef>
Execute the expression given the input arguments.
Sourcepub fn reduce(
&self,
node: &dyn ReduceNode,
ctx: &dyn ReduceCtx,
) -> VortexResult<Option<ReduceNodeRef>>
pub fn reduce( &self, node: &dyn ReduceNode, ctx: &dyn ReduceCtx, ) -> VortexResult<Option<ReduceNodeRef>>
Perform abstract reduction on this scalar function node.