pub trait ScalarFnVTableExt: ScalarFnVTable {
// Provided methods
fn bind(&self, options: Self::Options) -> ScalarFnRef { ... }
fn new_expr(
&self,
options: Self::Options,
children: impl IntoIterator<Item = Expression>,
) -> Expression { ... }
fn try_new_expr(
&self,
options: Self::Options,
children: impl IntoIterator<Item = Expression>,
) -> VortexResult<Expression> { ... }
}Expand description
Factory functions for vtables.
Provided Methods
Sourcefn bind(&self, options: Self::Options) -> ScalarFnRef
fn bind(&self, options: Self::Options) -> ScalarFnRef
Bind this vtable with the given options into a ScalarFnRef.
Sourcefn new_expr(
&self,
options: Self::Options,
children: impl IntoIterator<Item = Expression>,
) -> Expression
fn new_expr( &self, options: Self::Options, children: impl IntoIterator<Item = Expression>, ) -> Expression
Create a new expression with this vtable and the given options and children.
Sourcefn try_new_expr(
&self,
options: Self::Options,
children: impl IntoIterator<Item = Expression>,
) -> VortexResult<Expression>
fn try_new_expr( &self, options: Self::Options, children: impl IntoIterator<Item = Expression>, ) -> VortexResult<Expression>
Try to create a new expression with this vtable and the given options and children.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".