Module serde

Module serde 

Structs

ArrayNodeFlatBuffer
A utility struct for creating an fba::ArrayNode flatbuffer.
SerializeOptions
Options for serializing an array.
SerializedArray
SerializedArray represents a parsed but not-yet-decoded deserialized array. It contains all the information from the serialized form, without anything extra. i.e. it is missing a DType and len, and the encoding_id is not yet resolved to a concrete vtable.

Traits

ArrayChildren
To minimize the serialized form, arrays do not persist their own dtype and length. Instead, parent arrays pass this information down during deserialization.