pub trait ArrayChildren {
// Required methods
fn get(
&self,
index: usize,
dtype: &DType,
len: usize,
) -> VortexResult<ArrayRef>;
fn len(&self) -> usize;
// Provided method
fn is_empty(&self) -> bool { ... }
}Expand description
To minimize the serialized form, arrays do not persist their own dtype and length. Instead, parent arrays pass this information down during deserialization.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".