Traits and utilities to compute and access array statistics.
Re-exports
pub use expr::min_max;pub use expr::nan_count;pub use expr::null_count;pub use expr::stat;pub use expr::sum;pub use session::*;
Modules
- expr
- Expression constructors for statistics backed by aggregate functions.
- flatbuffers
- session
- Session state for stats APIs.
Structs
- Array
Stats - A shared
StatsSetstored in an array. Can be shared by copies of the array and can also be mutated in place. - MutTyped
Stats SetRef - Stats
Set - Stats
SetInto Iter - Owned iterator over the stats.
- Stats
SetRef - Reference to an array’s
StatsSet. Can be used to get and mutate the underlying stats. - Typed
Stats SetRef
Constants
- PRUNING_
STATS - Statistics that are used for pruning files (i.e., we want to ensure they are computed when compressing/writing). Sum is included for boolean arrays.
Functions
Type Aliases
- Stats
Array - Type of the SmallVec stored inside StatsSet