bind_stats

Function bind_stats 

pub fn bind_stats<B: StatBinder + ?Sized>(
    predicate: Expression,
    binder: &B,
) -> VortexResult<Expression>
Bind all vortex.stat expressions in predicate.

The predicate is usually the output of a stats rewrite rule. Rewrite rules are responsible for expressing stat semantics; binding maps aggregate-backed stat requests to the concrete stats representation supported by the binder.