Module bound

Module bound 

Constructors for statistic expressions whose input has already been bound.

These mirror the constructors in crate::stats and panic when the aggregate does not support the input dtype.

Functions

all_nan
Creates a bound nullable all-NaN statistic expression.
all_non_nan
Creates a bound nullable all-non-NaN statistic expression.
all_non_null
Creates a bound nullable all-non-null statistic expression.
all_null
Creates a bound nullable all-null statistic expression.
min_max
Creates a bound nullable { min, max } statistic expression.
nan_count
Creates a bound nullable NaN-count statistic expression.
null_count
Creates a bound nullable null-count statistic expression.
stat
Creates a bound expression that reads a stored aggregate statistic.
sum
Creates a bound nullable sum statistic expression.