pub fn stat(
expr: BoundExpression,
aggregate_fn: AggregateFnRef,
) -> BoundExpressionExpand description
Creates a bound expression that reads a stored aggregate statistic.
pub fn stat(
expr: BoundExpression,
aggregate_fn: AggregateFnRef,
) -> BoundExpressionCreates a bound expression that reads a stored aggregate statistic.