stat

Function stat 

pub fn stat(expr: Expression, aggregate_fn: AggregateFnRef) -> Expression
Creates an expression that reads a stored aggregate statistic for expr.

If the statistic is not available in the current stats scope, evaluating the expression returns a nullable all-null array with the aggregate return type.