ArrayRef

Struct ArrayRef 

pub struct ArrayRef(/* private fields */);
A reference-counted pointer to a type-erased array.

Implementations

Source

impl ArrayRef

pub fn ptr_eq(this: &ArrayRef, other: &ArrayRef) -> bool

Returns true if the two ArrayRefs point to the same allocation.

Source

impl ArrayRef

pub fn len(&self) -> usize

Returns the length of the array.

pub fn is_empty(&self) -> bool

Returns whether the array is empty (has zero rows).

pub fn dtype(&self) -> &DType

Returns the logical Vortex DType of the array.

pub fn encoding_id(&self) -> ArrayId

Returns the encoding ID of the array.

pub fn slice(&self, range: Range<usize>) -> VortexResult<ArrayRef>

Performs a constant-time slice of the array.

pub fn filter(&self, mask: Mask) -> VortexResult<ArrayRef>

Wraps the array in a FilterArray such that it is logically filtered by the given mask.

pub fn take(&self, indices: ArrayRef) -> VortexResult<ArrayRef>

Wraps the array in a DictArray such that it is logically taken by the given indices.

pub fn scalar_at(&self, index: usize) -> VortexResult<Scalar>

Fetch the scalar at the given index.

pub fn is_valid(&self, index: usize) -> VortexResult<bool>

Returns whether the item at index is valid.

pub fn is_invalid(&self, index: usize) -> VortexResult<bool>

Returns whether the item at index is invalid.

pub fn all_valid(&self) -> VortexResult<bool>

Returns whether all items in the array are valid.

pub fn all_invalid(&self) -> VortexResult<bool>

Returns whether the array is all invalid.

pub fn valid_count(&self) -> VortexResult<usize>

Returns the number of valid elements in the array.

pub fn invalid_count(&self) -> VortexResult<usize>

Returns the number of invalid elements in the array.

pub fn validity(&self) -> VortexResult<Validity>

Returns the Validity of the array.

pub fn validity_mask(&self) -> VortexResult<Mask>

Returns the canonical validity mask for the array.

pub fn into_canonical(self) -> VortexResult<Canonical>

Returns the canonical representation of the array.

pub fn to_canonical(&self) -> VortexResult<Canonical>

Returns the canonical representation of the array.

pub fn append_to_builder( &self, builder: &mut dyn ArrayBuilder, ctx: &mut ExecutionCtx, ) -> VortexResult<()>

Writes the array into the canonical builder.

pub fn statistics(&self) -> StatsSetRef<'_>

Returns the statistics of the array.

pub fn is<M: Matcher>(&self) -> bool

Does the array match the given matcher.

pub fn as_<M: Matcher>(&self) -> M::Match<'_>

Returns the array downcast by the given matcher.

pub fn as_opt<M: Matcher>(&self) -> Option<M::Match<'_>>

Returns the array downcast by the given matcher.

pub fn try_downcast<V: VTable>(self) -> Result<Array<V>, ArrayRef>

Returns the array downcast to the given Array<V> as an owned typed handle.

pub fn downcast<V: VTable>(self) -> Array<V>

Returns the array downcast to the given Array<V> as an owned typed handle.

Panics

Panics if the array is not of the given type.

pub fn as_typed<V: VTable>(&self) -> Option<ArrayView<'_, V>>

Returns a reference to the typed ArrayInner<V> if this array matches the given vtable type.

pub fn as_constant(&self) -> Option<Scalar>

Returns the constant scalar if this is a constant array.

pub fn nbytes(&self) -> u64

Total size of the array in bytes, including all children and buffers.

pub fn is_arrow(&self) -> bool

Returns whether this array is an arrow encoding.

pub fn is_canonical(&self) -> bool

Whether the array is of a canonical encoding.

pub fn with_slot( self, slot_idx: usize, replacement: ArrayRef, ) -> VortexResult<ArrayRef>

Returns a new array with the slot at slot_idx replaced by replacement.

This is only valid for physical rewrites: the replacement must have the same logical DType and len as the existing slot.

Takes ownership to allow in-place mutation when the refcount is 1.

pub fn with_slots(self, slots: Vec<Option<ArrayRef>>) -> VortexResult<ArrayRef>

Returns a new array with the provided slots.

This is only valid for physical rewrites: slot count, presence, logical DType, and logical len must remain unchanged.

pub fn reduce(&self) -> VortexResult<Option<ArrayRef>>

pub fn reduce_parent( &self, parent: &ArrayRef, child_idx: usize, ) -> VortexResult<Option<ArrayRef>>

pub fn execute_parent( &self, parent: &ArrayRef, child_idx: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Option<ArrayRef>>

pub fn children(&self) -> Vec<ArrayRef>

Returns the children of the array.

pub fn nchildren(&self) -> usize

Returns the number of children of the array.

pub fn nth_child(&self, idx: usize) -> Option<ArrayRef>

Returns the nth child of the array without allocating a Vec.

pub fn children_names(&self) -> Vec<String>

Returns the names of the children of the array.

pub fn named_children(&self) -> Vec<(String, ArrayRef)>

Returns the array’s children with their names.

pub fn buffers(&self) -> Vec<ByteBuffer>

Returns the data buffers of the array.

pub fn buffer_handles(&self) -> Vec<BufferHandle>

Returns the buffer handles of the array.

pub fn buffer_names(&self) -> Vec<String>

Returns the names of the buffers of the array.

pub fn named_buffers(&self) -> Vec<(String, BufferHandle)>

Returns the array’s buffers with their names.

pub fn nbuffers(&self) -> usize

Returns the number of data buffers of the array.

pub fn slots(&self) -> &[Option<ArrayRef>]

Returns the slots of the array.

pub fn slot_name(&self, idx: usize) -> String

Returns the name of the slot at the given index.

pub fn metadata(&self, session: &VortexSession) -> VortexResult<Option<Vec<u8>>>

Returns the serialized metadata of the array.

pub fn metadata_fmt(&self, f: &mut Formatter<'_>) -> Result

Formats a human-readable metadata description.

pub fn is_host(&self) -> bool

Returns whether all buffers are host-resident.

pub fn nbuffers_recursive(&self) -> usize

Count the number of buffers encoded by self and all child arrays.

pub fn depth_first_traversal(&self) -> DepthFirstArrayIterator

Depth-first traversal of the array and its children.

Source

impl ArrayRef

pub fn display_values(&self) -> impl Display

Display logical values of the array

For example, an i16 typed array containing the first five non-negative integers is displayed as: [0i16, 1i16, 2i16, 3i16, 4i16].

Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
assert_eq!(
    format!("{}", array.display_values()),
    "[0i16, 1i16, 2i16, 3i16, 4i16]",
)

See also: Array::display_as, DisplayArrayAs, and DisplayOptions.

pub fn display_as(&self, options: DisplayOptions) -> impl Display

Display the array as specified by the options.

See DisplayOptions for examples.

pub fn display_tree_encodings_only(&self) -> TreeDisplay

Display the tree of array encodings and lengths without metadata, buffers, or stats.

Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5)\n";
assert_eq!(format!("{}", array.display_tree_encodings_only()), expected);

let array = StructArray::from_fields(&[
    ("x", buffer![1, 2].into_array()),
    ("y", buffer![3, 4].into_array()),
]).unwrap().into_array();
let expected = "root: vortex.struct({x=i32, y=i32}, len=2)
  x: vortex.primitive(i32, len=2)
  y: vortex.primitive(i32, len=2)
";
assert_eq!(format!("{}", array.display_tree_encodings_only()), expected);
pub fn display_tree(&self) -> TreeDisplay

Display the tree of encodings of this array as an indented lists.

While some metadata (such as length, bytes and validity-rate) are included, the logical values of the array are not displayed. To view the logical values see Array::display_as and DisplayOptions.

Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)
  metadata: ptype: i16
  buffer: values host 10 B (align=2) (100.00%)
";
assert_eq!(format!("{}", array.display_tree()), expected);
pub fn tree_display(&self) -> TreeDisplay

Create a tree display with all built-in extractors (nbytes, stats, metadata, buffers).

This is the default, fully-detailed tree display. Use tree_display_builder() for a blank slate.

Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
let expected = "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)
  metadata: ptype: i16
  buffer: values host 10 B (align=2) (100.00%)
";
assert_eq!(array.tree_display().to_string(), expected);
pub fn tree_display_builder(&self) -> TreeDisplay

Create a composable tree display builder with no extractors.

With no extractors, only the node names are shown. Add extractors with .with() to include additional information. Most builders should start with EncodingSummaryExtractor to include encoding headers.

Examples
use vortex_array::display::{EncodingSummaryExtractor, NbytesExtractor, MetadataExtractor, BufferExtractor};

let array = buffer![0_i16, 1, 2, 3, 4].into_array();

// Encodings only
let encodings = array.tree_display_builder()
    .with(EncodingSummaryExtractor)
    .to_string();
assert_eq!(encodings, "root: vortex.primitive(i16, len=5)\n");

// With encoding + nbytes
let with_nbytes = array.tree_display_builder()
    .with(EncodingSummaryExtractor)
    .with(NbytesExtractor)
    .to_string();
assert_eq!(with_nbytes, "root: vortex.primitive(i16, len=5) nbytes=10 B (100.00%)\n");

// With encoding, metadata, and buffers
let detailed = array.tree_display_builder()
    .with(EncodingSummaryExtractor)
    .with(MetadataExtractor)
    .with(BufferExtractor { show_percent: false })
    .to_string();
let expected = "root: vortex.primitive(i16, len=5)\n  metadata: ptype: i16\n  buffer: values host 10 B (align=2)\n";
assert_eq!(detailed, expected);
pub fn display_table(&self) -> impl Display

Display the array as a formatted table.

For struct arrays, displays a column for each field in the struct. For regular arrays, displays a single column with values.

Examples
let s = StructArray::from_fields(&[
    ("x", buffer![1, 2].into_array()),
    ("y", buffer![3, 4].into_array()),
]).unwrap().into_array();
let expected = "
┌──────┬──────┐
│  x   │  y   │
├──────┼──────┤
│ 1i32 │ 3i32 │
├──────┼──────┤
│ 2i32 │ 4i32 │
└──────┴──────┘".trim();
assert_eq!(format!("{}", s.display_table()), expected);
Source

impl ArrayRef

pub fn execute<E: Executable>(self, ctx: &mut ExecutionCtx) -> VortexResult<E>

Execute this array to produce an instance of E.

See the Executable implementation for details on how this execution is performed.

pub fn execute_as<E: Executable>( self, _name: &'static str, ctx: &mut ExecutionCtx, ) -> VortexResult<E>

Execute this array, labeling the execution step with a name for tracing.

pub fn execute_until<M: Matcher>( self, ctx: &mut ExecutionCtx, ) -> VortexResult<ArrayRef>

Iteratively execute this array until the Matcher matches, using an explicit work stack.

The scheduler repeatedly:

  1. Checks if the current array matches M — if so, pops the stack or returns.
  2. Runs execute_parent on each child for child-driven optimizations.
  3. Calls execute which returns an ExecutionStep.

Note: the returned array may not match M. If execution converges to a canonical form that does not match M, the canonical array is returned since no further execution progress is possible.

For safety, we will error when the number of execution iterations reaches a configurable maximum (default 128, override with VORTEX_MAX_ITERATIONS).

Source

impl ArrayRef

pub fn apply(self, expr: &Expression) -> VortexResult<ArrayRef>

Apply the expression to this array, producing a new array in constant time.

Source

impl ArrayRef

pub fn to_array_iterator(&self) -> impl ArrayIterator + 'static

Create an ArrayIterator over the array.

Source

impl ArrayRef

pub fn normalize( self, options: &mut NormalizeOptions<'_>, ) -> VortexResult<ArrayRef>

Normalize the array according to given options.

This operation performs a recursive traversal of the array. Any non-allowed encoding is normalized per the configured operation.

Source

impl ArrayRef

pub fn serialize( &self, ctx: &ArrayContext, session: &VortexSession, options: &SerializeOptions, ) -> VortexResult<Vec<ByteBuffer>>

Serialize the array into a sequence of byte buffers that should be written contiguously. This function returns a vec to avoid copying data buffers.

Optionally, padding can be included to guarantee buffer alignment and ensure zero-copy reads within the context of an external file or stream. In this case, the alignment of the first byte buffer should be respected when writing the buffers to the stream or file.

The format of this blob is a sequence of data buffers, possible with prefixed padding, followed by a flatbuffer containing an fba::Array message, and ending with a little-endian u32 describing the length of the flatbuffer message.

Source

impl ArrayRef

pub fn to_array_stream(&self) -> impl ArrayStream + 'static

Create an ArrayStream over the array.

Source

impl ArrayRef

pub fn as_null_typed(&self) -> NullTyped<'_>

Downcasts the array for null-specific behavior.

pub fn as_bool_typed(&self) -> BoolTyped<'_>

Downcasts the array for bool-specific behavior.

pub fn as_primitive_typed(&self) -> PrimitiveTyped<'_>

Downcasts the array for primitive-specific behavior.

pub fn as_decimal_typed(&self) -> DecimalTyped<'_>

Downcasts the array for decimal-specific behavior.

pub fn as_utf8_typed(&self) -> Utf8Typed<'_>

Downcasts the array for utf8-specific behavior.

pub fn as_binary_typed(&self) -> BinaryTyped<'_>

Downcasts the array for binary-specific behavior.

pub fn as_struct_typed(&self) -> StructTyped<'_>

Downcasts the array for struct-specific behavior.

pub fn as_list_typed(&self) -> ListTyped<'_>

Downcasts the array for list-specific behavior.

pub fn as_extension_typed(&self) -> ExtensionTyped<'_>

Downcasts the array for extension-specific behavior.

pub fn try_to_mask_fill_null_false( &self, ctx: &mut ExecutionCtx, ) -> VortexResult<Mask>