Module test_harness

Module test_harness 

Modules

trace
Snapshot-friendly tracing harness for the optimizer and executor.

Functions

check_metadata
Check that a named metadata matches its previous versioning.
to_int_indices
Outputs the indices of the true values in a BoolArray