pub fn to_int_indices(
indices_bits: BoolArray,
ctx: &mut ExecutionCtx,
) -> VortexResult<Vec<u64>>Expand description
Outputs the indices of the true values in a BoolArray
pub fn to_int_indices(
indices_bits: BoolArray,
ctx: &mut ExecutionCtx,
) -> VortexResult<Vec<u64>>Outputs the indices of the true values in a BoolArray