ArrayEq

Trait ArrayEq 

pub trait ArrayEq {
    // Required method
    fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool;
}
An equality trait for arrays that represents structural equality with a configurable equality mode. This trait is used primarily to implement common subtree elimination and other array-based caching mechanisms.

The equality mode defines what level of structural equality is represented. See EqMode for more details.

Required Methods

fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ArrayEq for BitBuffer

Source

fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool

Source

impl ArrayEq for Mask

Source

fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool

Source

impl<T: ArrayEq> ArrayEq for Option<T>

Source

fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool

Source

impl<T: PartialEq> ArrayEq for Buffer<T>

Source

fn array_eq(&self, other: &Self, eq_mode: EqMode) -> bool

Implementors