pub trait ArrayHash {
// Required method
fn array_hash<H: Hasher>(&self, state: &mut H, eq_mode: EqMode);
}Expand description
A hash trait for arrays that represents structural equality with a configurable equality mode. This trait is used primarily to implement common subtree elimination and other array-based caching mechanisms.
The equality mode defines what level of structural equality is represented. See
EqMode for more details.
Note that where EqMode::Ptr is used, the hash is only valid for the lifetime of the
object.
Required Methods
fn array_hash<H: Hasher>(&self, state: &mut H, eq_mode: EqMode)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".