IntoArray

Trait IntoArray 

pub trait IntoArray {
    // Required method
    fn into_array(self) -> ArrayRef;
}
Trait for converting a type into a Vortex ArrayRef.

Required Methods

fn into_array(self) -> ArrayRef

Convert this value into the erased array handle used by generic APIs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoArray for &MaskValues

Source

impl IntoArray for BitBuffer

Source

impl IntoArray for BitBufferMut

Source

impl IntoArray for BooleanBuffer

Source

impl IntoArray for Buffer

Source

impl IntoArray for Mask

Source

impl<O> IntoArray for OffsetBuffer<O>

Source

impl<T: NativePType> IntoArray for Buffer<T>

Source

impl<T: NativePType> IntoArray for BufferMut<T>

Source

impl<T> IntoArray for ScalarBuffer<T>

Source

impl<V: VTable> IntoArray for Arc<Array<V>>

Implementors