ToCanonical

Trait ToCanonical 

pub trait ToCanonical {
    // Required methods
    fn to_null(&self) -> NullArray;
    fn to_bool(&self) -> BoolArray;
    fn to_primitive(&self) -> PrimitiveArray;
    fn to_decimal(&self) -> DecimalArray;
    fn to_struct(&self) -> StructArray;
    fn to_listview(&self) -> ListViewArray;
    fn to_fixed_size_list(&self) -> FixedSizeListArray;
    fn to_varbinview(&self) -> VarBinViewArray;
    fn to_extension(&self) -> ExtensionArray;
}
๐Ÿ‘ŽDeprecated:

use array.execute::<T>(ctx) instead

Trait for types that can be converted from an owned type into an owned array variant.

Canonicalization

This trait has a blanket implementation for all types implementing ToCanonical.

Required Methods

fn to_null(&self) -> NullArray

๐Ÿ‘ŽDeprecated:

use array.execute::<NullArray>(ctx) instead

Canonicalize into a NullArray if the target is Null typed.

fn to_bool(&self) -> BoolArray

๐Ÿ‘ŽDeprecated:

use array.execute::<BoolArray>(ctx) instead

Canonicalize into a BoolArray if the target is Bool typed.

fn to_primitive(&self) -> PrimitiveArray

๐Ÿ‘ŽDeprecated:

use array.execute::<PrimitiveArray>(ctx) instead

Canonicalize into a PrimitiveArray if the target is Primitive typed.

fn to_decimal(&self) -> DecimalArray

๐Ÿ‘ŽDeprecated:

use array.execute::<DecimalArray>(ctx) instead

Canonicalize into a DecimalArray if the target is Decimal typed.

fn to_struct(&self) -> StructArray

๐Ÿ‘ŽDeprecated:

use array.execute::<StructArray>(ctx) instead

Canonicalize into a StructArray if the target is Struct typed.

fn to_listview(&self) -> ListViewArray

๐Ÿ‘ŽDeprecated:

use array.execute::<ListViewArray>(ctx) instead

Canonicalize into a ListViewArray if the target is List typed.

fn to_fixed_size_list(&self) -> FixedSizeListArray

๐Ÿ‘ŽDeprecated:

use array.execute::<FixedSizeListArray>(ctx) instead

Canonicalize into a FixedSizeListArray if the target is List typed.

fn to_varbinview(&self) -> VarBinViewArray

๐Ÿ‘ŽDeprecated:

use array.execute::<VarBinViewArray>(ctx) instead

Canonicalize into a VarBinViewArray if the target is Utf8 or Binary typed.

fn to_extension(&self) -> ExtensionArray

๐Ÿ‘ŽDeprecated:

use array.execute::<ExtensionArray>(ctx) instead

Canonicalize into an ExtensionArray if the array is Extension typed.

Implementors