pub trait ValidityChildSliceHelper {
// Required method
fn unsliced_child_and_slice(&self) -> (&ArrayRef, usize, usize);
// Provided method
fn sliced_child_array(&self) -> VortexResult<ArrayRef> { ... }
}Expand description
Helper for encodings that keep an unsliced validity child plus a local slice range.
Required Methods
Sourcefn unsliced_child_and_slice(&self) -> (&ArrayRef, usize, usize)
fn unsliced_child_and_slice(&self) -> (&ArrayRef, usize, usize)
Returns (unsliced_validity, start, stop) for this array’s logical slice.
Provided Methods
Sourcefn sliced_child_array(&self) -> VortexResult<ArrayRef>
fn sliced_child_array(&self) -> VortexResult<ArrayRef>
Returns a sliced validity child array for the logical range.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".