ValidityVTable

Trait ValidityVTable 

pub trait ValidityVTable<V: VTable> {
    // Required method
    fn validity(array: ArrayView<'_, V>) -> VortexResult<Validity>;
}
Validity access for nullable instances of an encoding.

Non-nullable arrays bypass this hook and report Validity::NonNullable. Nullable arrays call into the encoding so it can expose either a constant validity state or a row-aligned boolean child array.

Required Methods

fn validity(array: ArrayView<'_, V>) -> VortexResult<Validity>

Returns the Validity of the array.

Pre-conditions
  • The array DType is nullable.
Post-conditions

If this returns Validity::Array, the child array must have the same length as array and non-nullable boolean dtype.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors