pub fn is_constant(
array: &ArrayRef,
ctx: &mut ExecutionCtx,
) -> VortexResult<bool>Expand description
Compute whether an array has constant values.
An array is constant IFF at least one of the following conditions apply:
- It has at least one element (Note - an empty array isn’t constant).
- It’s encoded as a
ConstantArrayorNullArray - Has an exact statistic attached to it, saying its constant.
- Is all invalid.
- Is all valid AND has minimum and maximum statistics that are equal.