min_max

Function min_max 

pub fn min_max(
    array: &ArrayRef,
    ctx: &mut ExecutionCtx,
) -> VortexResult<Option<MinMaxResult>>
The minimum and maximum non-null values of an array, or None if there are no non-null values.

The result scalars have the non-nullable version of the array dtype. This will update the stats set of the array as a side effect.