pub trait DynAggregateKernel:
'static
+ Send
+ Sync
+ Debug {
// Required method
fn aggregate(
&self,
aggregate_fn: &AggregateFnRef,
batch: &ArrayRef,
ctx: &mut ExecutionCtx,
) -> VortexResult<Option<Scalar>>;
}Expand description
A pluggable kernel for an aggregate function.
The provided array should be aggregated into a single scalar representing the partial state of a single group.
Required Methods
fn aggregate( &self, aggregate_fn: &AggregateFnRef, batch: &ArrayRef, ctx: &mut ExecutionCtx, ) -> VortexResult<Option<Scalar>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".