DynAggregateKernel

Trait DynAggregateKernel 

pub trait DynAggregateKernel:
    'static
    + Send
    + Sync
    + Debug {
    // Required method
    fn aggregate(
        &self,
        aggregate_fn: &AggregateFnRef,
        batch: &ArrayRef,
        ctx: &mut ExecutionCtx,
    ) -> VortexResult<Option<Scalar>>;
}
A pluggable kernel for an aggregate function.

The provided array should be aggregated into a single scalar representing the state of a single group.

Required Methods

fn aggregate( &self, aggregate_fn: &AggregateFnRef, batch: &ArrayRef, ctx: &mut ExecutionCtx, ) -> VortexResult<Option<Scalar>>

Implementors