AggregateFnPlugin

Trait AggregateFnPlugin 

pub trait AggregateFnPlugin:
    'static
    + Send
    + Sync {
    // Required methods
    fn id(&self) -> AggregateFnId;
    fn deserialize(
        &self,
        metadata: &[u8],
        session: &VortexSession,
    ) -> VortexResult<AggregateFnRef>;
}
Registry trait for ID-based deserialization of aggregate functions.

Plugins are registered in the session by their AggregateFnId. When a serialized aggregate function is encountered, the session resolves the ID to the plugin and calls deserialize to reconstruct the value as an AggregateFnRef.

Required Methods

fn id(&self) -> AggregateFnId

Returns the ID for this aggregate function.

fn deserialize( &self, metadata: &[u8], session: &VortexSession, ) -> VortexResult<AggregateFnRef>

Deserialize an aggregate function from serialized metadata.