pub trait TakeReduce: VTable {
// Required method
fn take(
array: ArrayView<'_, Self>,
indices: &ArrayRef,
) -> VortexResult<Option<ArrayRef>>;
}Required Methods
Sourcefn take(
array: ArrayView<'_, Self>,
indices: &ArrayRef,
) -> VortexResult<Option<ArrayRef>>
fn take( array: ArrayView<'_, Self>, indices: &ArrayRef, ) -> VortexResult<Option<ArrayRef>>
Take elements from an array at the given indices without reading buffers.
This trait is for take implementations that can operate purely on array metadata and
structure without needing to read or execute on the underlying buffers. Implementations
should return None if taking requires buffer access.
Preconditions
The indices are guaranteed to be non-empty.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl TakeReduce for Constant
impl TakeReduce for ListView
Metadata-only take for ListViewArray.