pub trait MapArrayExt: MapArraySlotsExt {
// Provided methods
fn entries_at(&self, index: usize) -> VortexResult<ArrayRef> { ... }
fn entry_count_at(&self, index: usize) -> usize { ... }
fn map_validity(&self) -> Validity { ... }
fn map_dtype(&self) -> &MapDType { ... }
fn keys_sorted(&self) -> bool { ... }
}Expand description
Accessors for the canonical map representation.
Provided Methods
Sourcefn entries_at(&self, index: usize) -> VortexResult<ArrayRef>
fn entries_at(&self, index: usize) -> VortexResult<ArrayRef>
Returns the entry structs for one map row.
Sourcefn entry_count_at(&self, index: usize) -> usize
fn entry_count_at(&self, index: usize) -> usize
Returns the number of entries in one map row.
Sourcefn map_validity(&self) -> Validity
fn map_validity(&self) -> Validity
Returns the outer map validity delegated from the entries list-view.
Sourcefn keys_sorted(&self) -> bool
fn keys_sorted(&self) -> bool
Returns whether producers assert sorted keys within each map value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".