Module primitive

Module primitive 

Structs

NativeValue
NativeValue serves as a wrapper type to allow us to implement Hash, Eq and other traits on all primitive types.
Primitive
PrimitiveArray
A primitive array that stores native types in a contiguous buffer of memory, along with an optional validity child.
PrimitiveArrayParts
PrimitiveMaskedValidityRule
Rule to push down validity masking from MaskedArray parent into PrimitiveArray child.

Functions

chunk_range
Computes the index range for a chunk, accounting for slice offset.
patch_chunk
Patches a chunk of decoded values.