Structs
- Native
Value - NativeValue serves as a wrapper type to allow us to implement Hash, Eq and other traits on all primitive types.
- Primitive
Array - A primitive array that stores native types in a contiguous buffer of memory, along with an optional validity child.
- Primitive
Array Parts - Primitive
Masked Validity Rule - Rule to push down validity masking from MaskedArray parent into PrimitiveArray child.
- PrimitiveV
Table
Constants
Functions
- chunk_
range - Computes the index range for a chunk, accounting for slice offset.
- compute_
is_ constant - Assumes any floating point has been cast into its bit representation for which != and !is_eq are the same Assumes there’s at least 1 value in the slice, which is an invariant of the entry level function.
- patch_
chunk - Patches a chunk of decoded values.