Module union

Module union 

Canonical sparse union arrays.

A UnionArray stores one u8 type ID per row followed by one row-aligned child for each variant. The type ID selects which child’s value is active for a row; values in all other children at that row are placeholders. Outer union nulls are stored as nulls in the type IDs child, independently of nulls in the selected variant child.

Type ID values are not validated during construction. Accessing a non-null row whose type ID is not declared by the union variants will panic.

Structs

Union
The canonical Union encoding.
UnionDataParts
Concrete parts of a UnionArray.

Traits

UnionArrayExt
Accessors for a canonical sparse union array.

Type Aliases

UnionArray
A canonical Union-encoded array.