Utilities to work with Arrow data and types.
Modules
Structs
- Arrow
Array Stream Adapter - An adapter for converting an
ArrowArrayStreamReaderinto a VortexArrayStream. - Arrow
Session - Session-scoped registry of Arrow extension plugins.
- Datum
- A wrapper around a generic Arrow array that can be used as a Datum in Arrow compute.
Enums
- Arrow
Export - Outcome of a successful call to
ArrowExportVTable::execute_arrow. - Arrow
Import - Outcome of a successful call to
ArrowImportVTable::from_arrow_array.
Traits
- Arrow
Array Executor Deprecated - Trait for executing a Vortex array to produce an Arrow array.
- Arrow
ExportV Table - Plugin layer for exporting a Vortex array to an Arrow extension type.
- Arrow
ImportV Table - Plugin layer for importing an Arrow extension-typed array into a Vortex extension array.
- Arrow
Session Ext - Extension trait for accessing the
ArrowSessionon a Vortex session. - From
Arrow Array - Into
Arrow Array Deprecated
Functions
- from_
arrow_ array_ with_ len - Convert an Arrow array to an Array with a specific length. This is useful for compute functions that delegate to Arrow using Datum, which will return a scalar (length 1 Arrow array) if the input array is constant.
- to_
arrow_ null_ buffer - Converts a
Validityto an ArrowNullBuffer, executing the validity array if needed. - to_
null_ buffer - Converts a mask to a null buffer.