Module arrow

Module arrow 

Utilities to work with Arrow data and types.

Modules

bool
byte_view
null
primitive

Structs

ArrowArrayStreamAdapter
An adapter for converting an ArrowArrayStreamReader into a Vortex ArrayStream.
Datum
A wrapper around a generic Arrow array that can be used as a Datum in Arrow compute.

Traits

ArrowArrayExecutor
Trait for executing a Vortex array to produce an Arrow array.
FromArrowArray
IntoArrowArray

Functions

from_arrow_array_with_len
Convert an Arrow array to an Array with a specific length. This is useful for compute functions that delegate to Arrow using Datum, which will return a scalar (length 1 Arrow array) if the input array is constant.