Compute kernels on top of Vortex Arrays.
We aim to provide a basic set of compute kernels that can be used to efficiently index, slice, and filter Vortex Arrays in their encoded forms.
Every array encoding has the ability to implement their own efficient implementations of these operators, else we will decode, and perform the equivalent operator from Arrow.
Re-exports
pub use crate::aggregate_fn::fns::min_max::MinMaxResult;
Modules
Structs
- Binary
Args - For binary compute functions, it’s useful to just have this short-cut.
- Compute
Fn - An instance of a compute function holding the implementation vtable and a set of registered compute kernels.
- Invocation
Args - Arguments to a compute function invocation.
- IsConstant
Opts - Configuration for
is_constant_optsoperations. - Unary
Args - For unary compute functions, it’s useful to just have this short-cut.
Enums
- Cost
- When calling
is_constantthe children are all checked for constantness. This enum decide at each precision/cost level the constant check should run as. The cost increase as we move down the list. - Input
- Input to a compute function.
- Output
- Output from a compute function.
Traits
- Compute
FnVTable - VTable for the implementation of a compute function.
- Kernel
- Compute functions can ask arrays for compute kernels for a given invocation.
- Options
- Options for a compute function invocation.
Functions
- is_
constant Deprecated - Computes whether an array has constant values.
- is_
constant_ opts Deprecated - Computes whether an array has constant values.
- is_
sorted Deprecated - Computes whether an array is sorted in non-decreasing order.
- is_
strict_ sorted Deprecated - Computes whether an array is strictly sorted in increasing order.
- min_max
Deprecated - nan_
count Deprecated - sum
Deprecated