Module compute

Module compute 

Compute kernels on top of Vortex Arrays.

We aim to provide a basic set of compute kernels that can be used to efficiently index, slice, and filter Vortex Arrays in their encoded forms.

Every array encoding has the ability to implement their own efficient implementations of these operators, else we will decode, and perform the equivalent operator from Arrow.

Modules

conformance

Structs

BinaryArgs
For binary compute functions, it’s useful to just have this short-cut.
ComputeFn
An instance of a compute function holding the implementation vtable and a set of registered compute kernels.
InvocationArgs
Arguments to a compute function invocation.
IsConstantKernelAdapter
IsConstantKernelRef
IsConstantOpts
Configuration for is_constant_opts operations.
IsSortedKernelAdapter
IsSortedKernelRef
MinMax
MinMaxKernelAdapter
MinMaxKernelRef
MinMaxResult
NaNCountKernelAdapter
NaNCountKernelRef
SumArgs
For unary compute functions, it’s useful to just have this short-cut.
SumKernelAdapter
SumKernelRef
UnaryArgs
For unary compute functions, it’s useful to just have this short-cut.

Enums

Cost
When calling is_constant the children are all checked for constantness. This enum decide at each precision/cost level the constant check should run as. The cost increase as we move down the list.
Input
Input to a compute function.
Output
Output from a compute function.

Traits

ComputeFnVTable
VTable for the implementation of a compute function.
IsConstantKernel
IsSortedIteratorExt
Helper methods to check sortedness with strictness
IsSortedKernel
Kernel
Compute functions can ask arrays for compute kernels for a given invocation.
MinMaxKernel
The minimum and maximum non-null values of an array, or None if there are no non-null/or non-nan values.
NaNCountKernel
Computes the min and max of an array, returning the (min, max) values
Options
Options for a compute function invocation.
SumKernel

Functions

is_constant
Computes whether an array has constant values. If the array’s encoding doesn’t implement the relevant VTable, it’ll try and canonicalize in order to make a determination.
is_constant_opts
Computes whether an array has constant values. Configurable by IsConstantOpts.
is_sorted
is_sorted_opts
is_strict_sorted
min_max
The minimum and maximum non-null values of an array, or None if there are no non-null values.
nan_count
Computes the number of NaN values in the array.
sum
Sum an array, starting from zero.
sum_impl
Sum an array.
warm_up_vtables
Force all the default ComputeFn vtables to register all available compute kernels.