Compute kernels on top of Vortex Arrays.
We aim to provide a basic set of compute kernels that can be used to efficiently index, slice, and filter Vortex Arrays in their encoded forms.
Every array encoding has the ability to implement their own efficient implementations of these operators, else we will decode, and perform the equivalent operator from Arrow.
Modules
Structs
- Binary
Args - For binary compute functions, it’s useful to just have this short-cut.
- Compute
Fn - An instance of a compute function holding the implementation vtable and a set of registered compute kernels.
- Invocation
Args - Arguments to a compute function invocation.
- IsConstant
Kernel Adapter - IsConstant
Kernel Ref - IsConstant
Opts - Configuration for
is_constant_optsoperations. - IsSorted
Kernel Adapter - IsSorted
Kernel Ref - MinMax
- MinMax
Kernel Adapter - MinMax
Kernel Ref - MinMax
Result - NaNCount
Kernel Adapter - NaNCount
Kernel Ref - SumArgs
- For unary compute functions, it’s useful to just have this short-cut.
- SumKernel
Adapter - SumKernel
Ref - Unary
Args - For unary compute functions, it’s useful to just have this short-cut.
Enums
- Cost
- When calling
is_constantthe children are all checked for constantness. This enum decide at each precision/cost level the constant check should run as. The cost increase as we move down the list. - Input
- Input to a compute function.
- Output
- Output from a compute function.
Traits
- Compute
FnVTable - VTable for the implementation of a compute function.
- IsConstant
Kernel - IsSorted
Iterator Ext - Helper methods to check sortedness with strictness
- IsSorted
Kernel - Kernel
- Compute functions can ask arrays for compute kernels for a given invocation.
- MinMax
Kernel - The minimum and maximum non-null values of an array, or None if there are no non-null/or non-nan values.
- NaNCount
Kernel - Computes the min and max of an array, returning the (min, max) values
- Options
- Options for a compute function invocation.
- SumKernel
Functions
- is_
constant - Computes whether an array has constant values. If the array’s encoding doesn’t implement the relevant VTable, it’ll try and canonicalize in order to make a determination.
- is_
constant_ opts - Computes whether an array has constant values. Configurable by
IsConstantOpts. - is_
sorted - is_
sorted_ opts - is_
strict_ sorted - min_max
- The minimum and maximum non-null values of an array, or None if there are no non-null values.
- nan_
count - Computes the number of NaN values in the array.
- sum
- Sum an array, starting from zero.
- sum_
impl - Sum an array.
- warm_
up_ vtables - Force all the default
ComputeFnvtables to register all available compute kernels.