Structs
- Buffer
Extractor - Extractor that adds buffer detail lines.
- Display
Array As - A shim used to display an array as specified in the options.
- Encoding
Summary Extractor - Extractor that adds the encoding summary (e.g.
vortex.primitive(i16, len=5)) to the header. - Indented
Formatter - Wrapper providing access to a
fmt::Formatterand the current indentation string. - Metadata
Extractor - Extractor that adds a
metadata: ...detail line. - Nbytes
Extractor - Extractor that adds
nbytes=X (Y%)to the header line. - Stats
Extractor - Extractor that adds stats annotations (e.g.
[nulls=3, min=5]) to the header line. - Tree
Context - Context threaded through tree traversal for percentage calculations etc.
- Tree
Display - Composable tree display builder.
Enums
- Display
Options - Describe how to convert an array to a string.
Traits
- Tree
Extractor - Trait for contributing display information to tree nodes.