pub struct FieldPath(/* private fields */);Expand description
A sequence of field selectors representing a path through zero or more layers of DType.
Examples
The empty path references the root:
use vortex_array::dtype::*;
let dtype_i32 = DType::Primitive(PType::I32, Nullability::NonNullable);
assert_eq!(dtype_i32, FieldPath::root().resolve(dtype_i32.clone()).unwrap());Implementations
Sourceimpl FieldPath
impl FieldPath
Sourcepub fn from_name<F: Into<FieldName>>(name: F) -> Self
pub fn from_name<F: Into<FieldName>>(name: F) -> Self
Constructs a new FieldPath from a single field selector (i.e., a direct child field of the top-level struct)
Sourcepub fn push<F: Into<Field>>(self, field: F) -> Self
pub fn push<F: Into<Field>>(self, field: F) -> Self
Pushes a new field selector to the end of this path
Sourcepub fn starts_with_field(&self, field: &Field) -> bool
pub fn starts_with_field(&self, field: &Field) -> bool
Whether the path starts with the given field name TODO(joe): handle asserts better.
Sourcepub fn resolve(&self, dtype: DType) -> Option<DType>
pub fn resolve(&self, dtype: DType) -> Option<DType>
The dtype, within the given type, to which this field path refers.
Note that a nullable DType may contain a non-nullable DType. This function returns the literal nullability of the child.
Examples
Extract the type of the “b” field from struct{a: list(struct{b: u32})?}:
use std::sync::Arc;
use vortex_array::dtype::*;
use vortex_array::dtype::Nullability::*;
let dtype = DType::Struct(
StructFields::from_iter([(
"a",
DType::List(
Arc::new(DType::Struct(
StructFields::from_iter([(
"b",
DType::Primitive(PType::U32, NonNullable),
)]),
NonNullable,
)),
Nullable,
),
)]),
NonNullable,
);
let path = FieldPath::from(vec![Field::from("a"), Field::ElementType, Field::from("b")]);
let resolved = path.resolve(dtype).unwrap();
assert_eq!(resolved, DType::Primitive(PType::U32, NonNullable));Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FieldPath
impl<'de> Deserialize<'de> for FieldPath
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl FromIterator<Field> for FieldPath
impl FromIterator<Field> for FieldPath
Sourceimpl FromIterator<FieldPath> for FieldPathSet
impl FromIterator<FieldPath> for FieldPathSet
impl Eq for FieldPath
impl StructuralPartialEq for FieldPath