pub enum ExecutionStep {
ExecuteChild(usize, DonePredicate),
Done(ArrayRef),
}Expand description
The result of a single execution step on an array encoding.
Instead of recursively executing children, encodings return an ExecutionStep that tells the
scheduler what to do next. This enables the scheduler to manage execution iteratively using
an explicit work stack, run cross-step optimizations, and cache shared sub-expressions.
Variants
ExecuteChild(usize, DonePredicate)
Request that the scheduler execute child at the given index, using the provided
DonePredicate to determine when the child is “done”, then replace the child in this
array and re-enter execution.
Between steps, the scheduler runs reduce/reduce_parent rules to fixpoint, enabling cross-step optimization (e.g., pushing scalar functions through newly-decoded children).
Use ExecutionStep::execute_child instead of constructing this variant directly.
Done(ArrayRef)
Execution is complete. The result may be in any encoding — not necessarily canonical. The scheduler will continue executing the result if it has not yet reached the target form.
Implementations