Re-exports
pub use annotation::*;pub use immediate_access::*;
Modules
Functions
- label_
bound_ tree - Label each node in a bound expression using identity-keyed lookups.
- label_
is_ fallible - label_
strict - Label each expression with whether its entire subtree is strict.
- label_
tree - Label each node in an expression tree using a bottom-up traversal.
- referenced_
field_ paths - Returns the rooted field paths referenced by an expression.
Type Aliases
- Boolean
Labels - Boolean labels keyed by each expression node in a tree.
- Bound
Labels - Labels keyed by bound-tree identity.