Re-exports
pub use annotation::*;pub use immediate_access::*;
Modules
Functions
- label_
is_ fallible - label_
null_ sensitive - Label each expression in the tree with whether it is null-sensitive.
- label_
tree - Label each node in an expression tree using a bottom-up traversal.
- referenced_
field_ paths - Returns the rooted field paths referenced by an expression.