pub fn direct_annotations<A: AnnotationFn>(
expr: &Expression,
annotate: A,
) -> Annotations<'_, A::Annotation>Expand description
Walk the expression tree and annotate each expression with zero or more annotations.
Returns a map of each expression to all annotations. Annotations of children are not propagated to parents.