pub fn label_strict(expr: &Expression) -> BooleanLabels<'_>Expand description
Label each expression with whether its entire subtree is strict.
A subtree is strict only when the node’s scalar function and every child subtree are strict.
See crate::scalar_fn::ScalarFnVTable::is_strict for the scalar-function contract.