Transformations for crate::expr::Expression and crate::expr::BoundExpression trees.
Structs
- Bound
Partitioned Expr - The result of partitioning a bound expression.
- Partitioned
Expr - The result of partitioning an expression.
Functions
- coerce_
expression - Rewrite an expression tree to insert casts where a scalar function’s
coerce_argsdemands a different type than what the child currently produces. - partition
- Partition an expression into sub-expressions that are uniquely associated with an annotation. A root expression is also returned that can be used to recombine the results of the partitions into the result of the original expression.
- partition_
annotations - partition_
bound - Partition an expression into sub-expressions that are uniquely associated with an annotation. A root expression is also returned that can be used to recombine the results of the partitions into the result of the original expression.
- partition_
bound_ annotations - Partition an already-annotated bound expression tree.
- replace
- Replaces all occurrences of
needlein the expressionexprwithreplacement. - replace_
root_ fields - Expand the
rootexpression with a pack of the given struct fields.