Extension Scalar Values, and interfaces for working with them.
We define normal Scalars as the combination of a ScalarValue and a DType.
Similarly, we define an extension Scalar as the combination of an ExtScalarValueRef and
an ExtDTypeRef.
Structs
- ExtScalar
Value - A typed extension scalar value, parameterized by a concrete
ExtVTable. - ExtScalar
Value Ref - A type-erased extension scalar value.