Scalar function vtable machinery.
This module contains the ScalarFnVTable trait and all built-in scalar function
implementations. Expressions (crate::expr::Expression) reference scalar functions
at each node.
Modules
Structs
- Empty
Options - Execution
Args - Arguments for expression execution.
- Scalar
Fn - A typed scalar function instance, parameterized by a concrete
ScalarFnVTable. - Scalar
FnOptions - An opaque handle to expression options.
- Scalar
FnPlugin - A Vortex scalar function vtable plugin, used to deserialize or instantiate scalar functions dynamically.
- Scalar
FnRef - A type-erased scalar function, pairing a vtable with bound options behind a trait object.
- Scalar
FnSignature - Information about the signature of an expression.
Enums
- Arity
- The arity (number of arguments) of a function.
Traits
- Reduce
Ctx - Arguments for reduction rules.
- Reduce
Node - A node used for implementing abstract reduction rules.
- Scalar
FnVTable - This trait defines the interface for scalar function vtables, including methods for serialization, deserialization, validation, child naming, return type computation, and evaluation.
- Scalar
FnVTable Ext - Factory functions for vtables.
- Simplify
Ctx - Context for simplification.
Type Aliases
- Child
Name - A reference to the name of a child expression.
- Reduce
Node Ref - Scalar
FnId - A unique identifier for a scalar function.