CastReduce

Trait CastReduce 

pub trait CastReduce: VTable {
    // Required method
    fn cast(
        array: &Self::Array,
        dtype: &DType,
    ) -> VortexResult<Option<ArrayRef>>;
}
Reduce rule for cast: restructure the array without reading buffers.

Encodings implement this to push cast operations through their structure. For example, RunEnd pushes cast down to its values array, ZigZag transforms the target dtype to unsigned and pushes to its encoded array.

Returns Ok(None) if the rule doesn’t apply to this array/dtype combination.

Required Methods

fn cast(array: &Self::Array, dtype: &DType) -> VortexResult<Option<ArrayRef>>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl CastReduce for Bool

Source

impl CastReduce for Chunked

Source

impl CastReduce for Constant

Source

impl CastReduce for Dict

Source

impl CastReduce for Extension

Source

impl CastReduce for FixedSizeList

Cast implementation for FixedSizeListArray.

Recursively casts the inner elements array to the target element type while preserving the list structure.

Source

impl CastReduce for List

Source

impl CastReduce for ListView

Source

impl CastReduce for Null

Source

impl CastReduce for VarBin

Source

impl CastReduce for VarBinView