Structs
- Fill
Null - An expression that replaces null values in the input with a fill value.
- Fill
Null Execute Adaptor - Adaptor that wraps a
FillNullKernelimpl as anExecuteParentKernel. - Fill
Null Reduce Adaptor - Adaptor that wraps a
FillNullReduceimpl as anArrayParentReduceRule.
Traits
- Fill
Null Kernel - Fill nulls in an array with a scalar value, potentially reading buffers.
- Fill
Null Reduce - Fill nulls in an array with a scalar value without reading buffers.