Structs
- Like
- Expression that performs SQL LIKE pattern matching.
- Like
Execute Adaptor - Adaptor that wraps a
LikeKernelimpl as anExecuteParentKernel. - Like
Options - Options for SQL LIKE function
- Like
Reduce Adaptor - Adaptor that wraps a
LikeReduceimpl as anArrayParentReduceRule.
Traits
- Like
Kernel - Like pattern matching on an array, potentially reading buffers.
- Like
Reduce - Like pattern matching on an array without reading buffers.