ScalarFnVTableExt

Trait ScalarFnVTableExt 

pub trait ScalarFnVTableExt: ScalarFnVTable {
    // Provided methods
    fn bind(&self, options: Self::Options) -> ScalarFnRef { ... }
    fn new_expr(
        &self,
        options: Self::Options,
        children: impl IntoIterator<Item = Expression>,
    ) -> Expression { ... }
    fn try_new_expr(
        &self,
        options: Self::Options,
        children: impl IntoIterator<Item = Expression>,
    ) -> VortexResult<Expression> { ... }
}
Factory functions for vtables.

Provided Methods

fn bind(&self, options: Self::Options) -> ScalarFnRef

Bind this vtable with the given options into a ScalarFnRef.

fn new_expr( &self, options: Self::Options, children: impl IntoIterator<Item = Expression>, ) -> Expression

Create a new expression with this vtable and the given options and children.

fn try_new_expr( &self, options: Self::Options, children: impl IntoIterator<Item = Expression>, ) -> VortexResult<Expression>

Try to create a new expression with this vtable and the given options and children.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors