Constructors for statistic expressions whose input has already been bound.
These mirror the constructors in crate::stats and panic when the aggregate does not support
the input dtype.
Functions
- all_nan
- Creates a bound nullable all-NaN statistic expression.
- all_
non_ nan - Creates a bound nullable all-non-NaN statistic expression.
- all_
non_ null - Creates a bound nullable all-non-null statistic expression.
- all_
null - Creates a bound nullable all-null statistic expression.
- min_max
- Creates a bound nullable
{ min, max }statistic expression. - nan_
count - Creates a bound nullable NaN-count statistic expression.
- null_
count - Creates a bound nullable null-count statistic expression.
- stat
- Creates a bound expression that reads a stored aggregate statistic.
- sum
- Creates a bound nullable sum statistic expression.