pub fn trace_op_with<T>(
options: TraceOptions,
f: impl FnOnce() -> VortexResult<T>,
) -> VortexResult<Traced<T>>Expand description
Run f while capturing a trace using options.
See trace_op for the common case. Use this when you need to override the default
TraceResolution to capture declined rules and unmatched kernels.
Trace capture is thread-local and intentionally does not propagate to worker threads. Nested trace captures return an error so tests do not accidentally merge unrelated traces.