pub trait IntoArray {
// Required method
fn into_array(self) -> ArrayRef;
}Expand description
Trait for converting a type into a Vortex ArrayRef.
Required Methods
Sourcefn into_array(self) -> ArrayRef
fn into_array(self) -> ArrayRef
Convert this value into the erased array handle used by generic APIs.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".