This module contains the VTable definitions for a Vortex encoding.
Structs
- Empty
Array Data - Empty array metadata struct for encodings with no per-array metadata.
- NotSupported
- Placeholder type used to indicate when a particular vtable is not supported by the encoding.
- ValidityV
Table From Child - An implementation of the
ValidityVTablefor arrays that delegate validity entirely to a child array. - ValidityV
Table From Child Slice Helper - An implementation of the
ValidityVTablefor arrays that hold an unsliced validity and a slice into it.
Traits
- Array
Plugin - Registry trait for ID-based deserialization of arrays.
- ArrayV
Table - Alias for migration — downstream code can start using
ArrayVTable. The arrayVTableencapsulates logic for an Array type within Vortex. - OperationsV
Table - VTable
- The array
VTableencapsulates logic for an Array type within Vortex. - Validity
Child - Validity
Child Slice Helper - ValidityV
Table
Functions
- child_
to_ validity - Reconstruct a
Validityfrom an optional child array and nullability. - patches_
child - Returns the child at the given index within a patches component.
- patches_
child_ name - Returns the name of the child at the given index within a patches component.
- patches_
nchildren - Returns the number of children produced by patches.
- validity_
nchildren - Returns 1 if validity produces a child, 0 otherwise.
- validity_
to_ child - Returns the validity as a child array if it produces one.
Type Aliases
- Array
Plugin Ref - Reference-counted array plugin.