Module vtable

Module vtable 

This module contains the VTable definitions for a Vortex encoding.

Structs

NotSupported
Placeholder type used to indicate when a particular vtable is not supported by the encoding.
ValidityVTableFromChild
An implementation of the ValidityVTable for arrays that delegate validity entirely to a child array.
ValidityVTableFromChildSliceHelper
An implementation of the ValidityVTable for arrays that hold an unsliced validity and a slice into it.
ValidityVTableFromValidityHelper
An implementation of the ValidityVTable for arrays that hold validity as a child array.
ValidityVTableFromValiditySliceHelper
An implementation of the ValidityVTable for arrays that hold an unsliced validity and a slice into it.

Traits

ArrayVTableExt
DynVTable
Dynamically typed vtable trait.
OperationsVTable
VTable
The array VTable encapsulates logic for an Array type within Vortex.
ValidityChild
ValidityChildSliceHelper
ValidityHelper
Expose validity held as a child array.
ValiditySliceHelper
ValidityVTable

Functions

patches_child
Returns the child at the given index within a patches component.
patches_child_name
Returns the name of the child at the given index within a patches component.
patches_nchildren
Returns the number of children produced by patches.
validity_nchildren
Returns 1 if validity produces a child, 0 otherwise.
validity_to_child
Returns the validity as a child array if it produces one.

Type Aliases

ArrayId
ArrayId is a globally unique name for the array’s vtable.