pub trait OperationsVTable<V: VTable> {
// Required method
fn scalar_at(
array: ArrayView<'_, V>,
index: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Scalar>;
}Expand description
Required Methods
Sourcefn scalar_at(
array: ArrayView<'_, V>,
index: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Scalar>
fn scalar_at( array: ArrayView<'_, V>, index: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Scalar>
Fetch the scalar at the given index.
Preconditions
Bounds-checking has already been performed by the time this function is called,
and the index is guaranteed to be non-null. Implementations may assume index < len.
Postconditions
The returned Scalar must have the same logical dtype as the array’s element dtype.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".