pub trait OperationsVTable<V: VTable> {
// Required method
fn scalar_at(
array: &V::Array,
index: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Scalar>;
}Required Methods
Sourcefn scalar_at(
array: &V::Array,
index: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Scalar>
fn scalar_at( array: &V::Array, index: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Scalar>
Fetch the scalar at the given index.
Preconditions
Bounds-checking has already been performed by the time this function is called, and the index is guaranteed to be non-null.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.